@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
+require_relative 'options_validator'
+
 module StateMachines
   # An event defines an action that transitions an attribute from one state to
   # another.  The state that an attribute is transitioned to depends on the
   # branches configured for the event.
   class Event
-
     include MatcherHelpers
 
     # The state machine for which this event is defined
@@ -30,13 +33,25 @@ module StateMachines
     #
     # Configuration options:
     # * <tt>:human_name</tt> - The human-readable version of this event's name
-    def initialize(machine, name, options = {}) #:nodoc:
-      options.assert_valid_keys(:human_name)
+    def initialize(machine, name, options = nil, human_name: nil, **extra_options) # :nodoc:
+      # Handle both old hash style and new kwargs style for backward compatibility
+      case options
+      in Hash
+        # Old style: initialize(machine, name, {human_name: 'Custom Name'})
+        StateMachines::OptionsValidator.assert_valid_keys!(options, :human_name)
+        human_name = options[:human_name]
+      in nil
+        # New style: initialize(machine, name, human_name: 'Custom Name')
+        StateMachines::OptionsValidator.assert_valid_keys!(extra_options, :human_name) unless extra_options.empty?
+      else
+        # Handle unexpected options
+        raise ArgumentError, "Unexpected positional argument in Event initialize: #{options.inspect}"
+      end
 
       @machine = machine
       @name = name
       @qualified_name = machine.namespace ? :"#{name}_#{machine.namespace}" : name
-      @human_name = options[:human_name] || @name.to_s.tr('_', ' ')
+      @human_name = human_name || @name.to_s.tr('_', ' ')
       reset
 
       # Output a warning if another event has a conflicting qualified name
@@ -50,7 +65,7 @@ module StateMachines
 
     # Creates a copy of this event in addition to the list of associated
     # branches to prevent conflicts across events within a class hierarchy.
-    def initialize_copy(orig) #:nodoc:
+    def initialize_copy(orig) # :nodoc:
       super
       @branches = @branches.dup
       @known_states = @known_states.dup
@@ -64,8 +79,8 @@ module StateMachines
 
     # Evaluates the given block within the context of this event.  This simply
     # provides a DSL-like syntax for defining transitions.
-    def context(&block)
-      instance_eval(&block)
+    def context(&)
+      instance_eval(&)
     end
 
     # Creates a new transition that determines what to change the current state
@@ -89,7 +104,7 @@ module StateMachines
 
       # Only a certain subset of explicit options are allowed for transition
       # requirements
-      options.assert_valid_keys(:from, :to, :except_from, :except_to, :if, :unless) if (options.keys - [:from, :to, :on, :except_from, :except_to, :except_on, :if, :unless]).empty?
+      StateMachines::OptionsValidator.assert_valid_keys!(options, :from, :to, :except_from, :except_to, :if, :unless, :if_state, :unless_state, :if_all_states, :unless_all_states, :if_any_state, :unless_any_state) if (options.keys - %i[from to on except_from except_to except_on if unless if_state unless_state if_all_states unless_all_states if_any_state unless_any_state]).empty?
 
       branches << branch = Branch.new(options.merge(on: name))
       @known_states |= branch.known_states
@@ -118,24 +133,26 @@ module StateMachines
     #   specified, then this will match any to state.
     # * <tt>:guard</tt> - Whether to guard transitions with the if/unless
     #   conditionals defined for each one.  Default is true.
-    def transition_for(object, requirements = {})
-      requirements.assert_valid_keys(:from, :to, :guard)
+    #
+    # Event arguments are passed to guard conditions if they accept multiple parameters.
+    def transition_for(object, requirements = {}, *event_args)
+      StateMachines::OptionsValidator.assert_valid_keys!(requirements, :from, :to, :guard)
       requirements[:from] = machine.states.match!(object).name unless (custom_from_state = requirements.include?(:from))
 
       branches.each do |branch|
-        if (match = branch.match(object, requirements))
-          # Branch allows for the transition to occur
-          from = requirements[:from]
-          to = if match[:to].is_a?(LoopbackMatcher)
-                 from
-               else
-                 values = requirements.include?(:to) ? [requirements[:to]].flatten : [from] | machine.states.map { |state| state.name }
+        next unless (match = branch.match(object, requirements, event_args))
 
-                 match[:to].filter(values).first
-               end
+        # Branch allows for the transition to occur
+        from = requirements[:from]
+        to = if match[:to].is_a?(LoopbackMatcher)
+               from
+             else
+               values = requirements.include?(:to) ? [requirements[:to]].flatten : [from] | machine.states.map { |state| state.name }
 
-          return Transition.new(object, machine, name, from, to, !custom_from_state)
-        end
+               match[:to].filter(values).first
+             end
+
+        return Transition.new(object, machine, name, from, to, !custom_from_state)
       end
 
       # No transition matched
@@ -148,13 +165,13 @@ module StateMachines
     #
     # Any additional arguments are passed to the StateMachines::Transition#perform
     # instance method.
-    def fire(object, *args)
+    def fire(object, *event_args)
       machine.reset(object)
 
-      if (transition = transition_for(object))
-        transition.perform(*args)
+      if (transition = transition_for(object, {}, *event_args))
+        transition.perform(*event_args)
       else
-        on_failure(object, *args)
+        on_failure(object, *event_args)
         false
       end
     end
@@ -179,9 +196,8 @@ module StateMachines
       @known_states = []
     end
 
-
-    def draw(graph, options = {})
-      fail NotImplementedError
+    def draw(graph, options = {}, io = $stdout)
+      machine.renderer.draw_event(self, graph, options, io)
     end
 
     # Generates a nicely formatted description of this event's contents.
@@ -192,16 +208,16 @@ module StateMachines
     #   event.transition all - :idling => :parked, :idling => same
     #   event   # => #<StateMachines::Event name=:park transitions=[all - :idling => :parked, :idling => same]>
     def inspect
-      transitions = branches.map do |branch|
+      transitions = branches.flat_map do |branch|
         branch.state_requirements.map do |state_requirement|
           "#{state_requirement[:from].description} => #{state_requirement[:to].description}"
-        end * ', '
-      end
+        end
+      end.join(', ')
 
-      "#<#{self.class} name=#{name.inspect} transitions=[#{transitions * ', '}]>"
+      "#<#{self.class} name=#{name.inspect} transitions=[#{transitions}]>"
     end
 
-  protected
+    protected
 
     # Add the various instance methods that can transition the object using
     # the current event
