@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module StateMachines
   module Integrations
     # Provides a set of base helpers for managing individual integrations
@@ -31,9 +33,15 @@ module StateMachines
         def matches_ancestors?(ancestors)
           (ancestors & matching_ancestors).any?
         end
+
+        # Additional options that this integration adds to the state machine.
+        # Integrations can override this method to specify additional valid options.
+        def integration_options
+          []
+        end
       end
 
-      def self.included(base) #:nodoc:
+      def self.included(base) # :nodoc:
         base.extend ClassMethods
       end
     end
