@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # A state machine is a model of behavior composed of states, events, and
 # transitions.  This helper adds support for defining this type of
 # functionality on any Ruby class.
@@ -513,8 +515,8 @@ module StateMachines
     # See StateMachines::Machine for more information about using integrations
     # and the individual integration docs for information about the actual
     # scopes that are generated.
-    def state_machine(*args, &block)
-      StateMachines::Machine.find_or_create(self, *args, &block)
+    def state_machine(*, &)
+      StateMachines::Machine.find_or_create(self, *, &)
     end
   end
 end
