@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module StateMachines
   # Provides a set of helper methods for generating matchers
   module MatcherHelpers
@@ -28,7 +30,7 @@ module StateMachines
     def all
       AllMatcher.instance
     end
-    alias_method :any, :all
+    alias any all
 
     # Represents a state that matches the original +from+ state.  This is useful
     # for defining transitions which are loopbacks.
