@@ -1,3 +1,7 @@
+# frozen_string_literal: true
+
+require_relative 'options_validator'
+
 module StateMachines
   # A state defines a value that an attribute can be in after being transitioned
   # 0 or more times.  States can represent a value of any type in Ruby, though
@@ -8,7 +12,6 @@ module StateMachines
   # StateMachines::Machine#state for more information about how state-driven
   # behavior can be utilized.
   class State
-
     # The state machine for which this state is defined
     attr_reader :machine
 
@@ -31,7 +34,7 @@ module StateMachines
 
     # Whether or not this state is the initial state to use for new objects
     attr_accessor :initial
-    alias_method :initial?, :initial
+    alias initial? initial
 
     # A custom lambda block for determining whether a given value matches this
     # state
@@ -50,38 +53,59 @@ module StateMachines
     #   (e.g. :value => lambda {Time.now}, :if => lambda {|state| !state.nil?}).
     #   By default, the configured value is matched.
     # * <tt>:human_name</tt> - The human-readable version of this state's name
-    def initialize(machine, name, options = {}) #:nodoc:
-      options.assert_valid_keys(:initial, :value, :cache, :if, :human_name)
+    def initialize(machine, name, options = nil, initial: false, value: :__not_provided__, cache: nil, if: nil, human_name: nil, **extra_options) # :nodoc:
+      # Handle both old hash style and new kwargs style for backward compatibility
+      case options
+      in Hash
+        # Old style: initialize(machine, name, {initial: true, value: 'foo'})
+        StateMachines::OptionsValidator.assert_valid_keys!(options, :initial, :value, :cache, :if, :human_name)
+        initial = options.fetch(:initial, false)
+        value = options.include?(:value) ? options[:value] : :__not_provided__
+        cache = options[:cache]
+        if_condition = options[:if]
+        human_name = options[:human_name]
+      in nil
+        # New style: initialize(machine, name, initial: true, value: 'foo')
+        StateMachines::OptionsValidator.assert_valid_keys!(extra_options, :initial, :value, :cache, :if, :human_name) unless extra_options.empty?
+        if_condition = binding.local_variable_get(:if) # 'if' is a keyword, need special handling
+      else
+        # Handle unexpected options
+        raise ArgumentError, "Unexpected positional argument in State initialize: #{options.inspect}"
+      end
 
       @machine = machine
       @name = name
       @qualified_name = name && machine.namespace ? :"#{machine.namespace}_#{name}" : name
-      @human_name = options[:human_name] || (@name ? @name.to_s.tr('_', ' ') : 'nil')
-      @value = options.include?(:value) ? options[:value] : name&.to_s
-      @cache = options[:cache]
-      @matcher = options[:if]
-      @initial = options[:initial] == true
+      @human_name = human_name || (@name ? @name.to_s.tr('_', ' ') : 'nil')
+      @value = value == :__not_provided__ ? name&.to_s : value
+      @cache = cache
+      @matcher = if_condition
+      @initial = initial == true
       @context = StateContext.new(self)
 
-      if name
-        conflicting_machines = machine.owner_class.state_machines.select { |other_name, other_machine| other_machine != machine && other_machine.states[qualified_name, :qualified_name] }
+      return unless name
 
-        # Output a warning if another machine has a conflicting qualified name
-        # for a different attribute
-        if (conflict = conflicting_machines.detect { |_other_name, other_machine| other_machine.attribute != machine.attribute })
-          _name, other_machine = conflict
-          warn "State #{qualified_name.inspect} for #{machine.name.inspect} is already defined in #{other_machine.name.inspect}"
-        elsif conflicting_machines.empty?
-          # Only bother adding predicates when another machine for the same
-          # attribute hasn't already done so
-          add_predicate
-        end
+      conflicting_machines = machine.owner_class.state_machines.select do |_other_name, other_machine|
+        other_machine != machine && other_machine.states[qualified_name, :qualified_name]
+      end
+
+      # Output a warning if another machine has a conflicting qualified name
+      # for a different attribute
+      if (conflict = conflicting_machines.detect do |_other_name, other_machine|
+        other_machine.attribute != machine.attribute
+      end)
+        _name, other_machine = conflict
+        warn "State #{qualified_name.inspect} for #{machine.name.inspect} is already defined in #{other_machine.name.inspect}"
+      elsif conflicting_machines.empty?
+        # Only bother adding predicates when another machine for the same
+        # attribute hasn't already done so
+        add_predicate
       end
     end
 
     # Creates a copy of this state, excluding the context to prevent conflicts
     # across different machines.
-    def initialize_copy(orig) #:nodoc:
+    def initialize_copy(orig) # :nodoc:
       super
       @context = StateContext.new(self)
     end
@@ -96,7 +120,7 @@ module StateMachines
     # Any objects in a final state will remain so forever given the current
     # machine's definition.
     def final?
-      !machine.events.any? do |event|
+      machine.events.none? do |event|
         event.branches.any? do |branch|
           branch.state_requirements.any? do |requirement|
             requirement[:from].matches?(name) && !requirement[:to].matches?(name, from: name)
@@ -126,7 +150,7 @@ module StateMachines
     #   description or just the internal name
     def description(options = {})
       label = options[:human_name] ? human_name : name
-      description = label ? label.to_s : label.inspect
+      description = +(label ? label.to_s : label.inspect)
       description << " (#{@value.is_a?(Proc) ? '*' : @value.inspect})" unless name.to_s == @value.to_s
       description
     end
@@ -178,27 +202,27 @@ module StateMachines
     #
     # This can be called multiple times.  Each time a new context is created,
     # a new module will be included in the owner class.
-    def context(&block)
+    def context(&)
       # Include the context
       context = @context
       machine.owner_class.class_eval { include context }
 
       # Evaluate the method definitions and track which ones were added
       old_methods = context_methods
-      context.class_eval(&block)
-      new_methods = context_methods.to_a.select { |(name, method)| old_methods[name] != method }
+      context.class_eval(&)
+      new_methods = context_methods.to_a.reject { |(name, method)| old_methods[name] == method }
 
       # Alias new methods so that the only execute when the object is in this state
       new_methods.each do |(method_name, _method)|
         context_name = context_name_for(method_name)
-        context.class_eval <<-end_eval, __FILE__, __LINE__ + 1
+        context.class_eval <<-END_EVAL, __FILE__, __LINE__ + 1
           alias_method :"#{context_name}", :#{method_name}
           def #{method_name}(*args, &block)
             state = self.class.state_machine(#{machine.name.inspect}).states.fetch(#{name.inspect})
             options = {:method_missing => lambda {super(*args, &block)}, :method_name => #{method_name.inspect}}
             state.call(self, :"#{context_name}", *(args + [options]), &block)
           end
-        end_eval
+        END_EVAL
       end
 
       true
@@ -216,31 +240,30 @@ module StateMachines
     #
     # If the method has never been defined for this state, then a NoMethodError
     # will be raised.
-    def call(object, method, *args, &block)
+    def call(object, method, *args, &)
       options = args.last.is_a?(Hash) ? args.pop : {}
-      options = {method_name: method}.merge(options)
+      options = { method_name: method }.merge(options)
       state = machine.states.match!(object)
 
       if state == self && object.respond_to?(method)
-        object.send(method, *args, &block)
-      elsif method_missing = options[:method_missing]
+        object.send(method, *args, &)
+      elsif (method_missing = options[:method_missing])
         # Dispatch to the superclass since the object either isn't in this state
         # or this state doesn't handle the method
         begin
           method_missing.call
-        rescue NoMethodError => ex
-          if ex.name.to_s == options[:method_name].to_s && ex.args == args
-            # No valid context for this method
-            raise InvalidContext.new(object, "State #{state.name.inspect} for #{machine.name.inspect} is not a valid context for calling ##{options[:method_name]}")
-          else
-            raise
-          end
+        rescue NoMethodError => e
+          raise unless e.name.to_s == options[:method_name].to_s && e.args == args
+
+          # No valid context for this method
+          raise InvalidContext.new(object,
+                                   "State #{state.name.inspect} for #{machine.name.inspect} is not a valid context for calling ##{options[:method_name]}")
         end
       end
     end
 
-    def draw(graph, options = {})
-      fail NotImplementedError
+    def draw(graph, options = {}, io = $stdout)
+      machine.renderer.draw_state(self, graph, options, io)
     end
 
     # Generates a nicely formatted description of this state's contents.
@@ -254,7 +277,7 @@ module StateMachines
       "#<#{self.class} #{attributes.map { |attr, value| "#{attr}=#{value.inspect}" } * ' '}>"
     end
 
-  private
+    private
 
     # Should the value be cached after it's evaluated for the first time?
     def cache_value?
@@ -264,9 +287,16 @@ module StateMachines
     # Adds a predicate method to the owner class so long as a name has
     # actually been configured for the state
     def add_predicate
-      # Checks whether the current value matches this state
-      machine.define_helper(:instance, "#{qualified_name}?") do |machine, object|
-        machine.states.matches?(object, name)
+      predicate_method = "#{qualified_name}?"
+
+      if machine.send(:owner_class_ancestor_has_method?, :instance, predicate_method)
+        warn_about_method_conflict(predicate_method, machine.owner_class.ancestors.first)
+      elsif machine.send(:owner_class_has_method?, :instance, predicate_method)
+        warn_about_method_conflict(predicate_method, machine.owner_class)
+      else
+        machine.define_helper(:instance, predicate_method) do |machine, object|
+          machine.states.matches?(object, name)
+        end
       end
     end
 
@@ -274,5 +304,11 @@ module StateMachines
     def context_name_for(method)
       :"__#{machine.name}_#{name}_#{method}_#{@context.object_id}__"
     end
+
+    def warn_about_method_conflict(method, defined_in)
+      return if StateMachines::Machine.ignore_method_conflicts
+
+      warn "Instance method #{method.inspect} is already defined in #{defined_in.inspect}, use generic helper instead or set StateMachines::Machine.ignore_method_conflicts = true."
+    end
   end
 end
