@@ -1,4 +1,11 @@
+# frozen_string_literal: true
+
 module StateMachines
+  # Module to extend Fiber instances for pausable state tracking
+  module PausableFiber
+    attr_accessor :state_machine_fiber_pausable
+  end
+
   # A transition represents a state change for a specific attribute.
   #
   # Transitions consist of:
@@ -28,19 +35,16 @@ module StateMachines
     # Whether the transition is only existing temporarily for the object
     attr_writer :transient
 
-    # Determines whether the current ruby implementation supports pausing and
-    # resuming transitions
-    def self.pause_supported?
-      %w(ruby maglev).include?(RUBY_ENGINE)
-    end
-
     # Creates a new, specific transition
-    def initialize(object, machine, event, from_name, to_name, read_state = true) #:nodoc:
+    def initialize(object, machine, event, from_name, to_name, read_state = true) # :nodoc:
       @object = object
       @machine = machine
       @args = []
       @transient = false
-      @resume_block = nil
+      @paused_fiber = nil
+      @resuming = false
+      @continuation_block = nil
+      @fiber_thread_storage = nil
 
       @event = machine.events.fetch(event)
       @from_state = machine.states.fetch(from_name)
@@ -134,7 +138,7 @@ module StateMachines
     #   transition = StateMachines::Transition.new(Vehicle.new, machine, :ignite, :parked, :idling)
     #   transition.attributes   # => {:object => #<Vehicle:0xb7d60ea4>, :attribute => :state, :event => :ignite, :from => 'parked', :to => 'idling'}
     def attributes
-      @attributes ||= {object: object, attribute: attribute, event: event, from: from, to: to}
+      @attributes ||= { object: object, attribute: attribute, event: event, from: from, to: to }
     end
 
     # Runs the actual transition and any before/after callbacks associated
@@ -151,25 +155,33 @@ module StateMachines
     #
     #   vehicle = Vehicle.new
     #   transition = StateMachines::Transition.new(vehicle, machine, :ignite, :parked, :idling)
-    #   transition.perform                  # => Runs the +save+ action after setting the state attribute
-    #   transition.perform(false)           # => Only sets the state attribute
-    #   transition.perform(Time.now)        # => Passes in additional arguments and runs the +save+ action
-    #   transition.perform(Time.now, false) # => Passes in additional arguments and only sets the state attribute
+    #   transition.perform                              # => Runs the +save+ action after setting the state attribute
+    #   transition.perform(false)                       # => Only sets the state attribute
+    #   transition.perform(run_action: false)           # => Only sets the state attribute
+    #   transition.perform(Time.now)                    # => Passes in additional arguments and runs the +save+ action
+    #   transition.perform(Time.now, false)             # => Passes in additional arguments and only sets the state attribute
+    #   transition.perform(Time.now, run_action: false) # => Passes in additional arguments and only sets the state attribute
     def perform(*args)
-      run_action = [true, false].include?(args.last) ? args.pop : true
+      run_action = case args.last
+                   in true | false
+                     args.pop
+                   in { run_action: }
+                     args.last.delete(:run_action)
+                   else
+                     true
+                   end
+
       self.args = args
 
       # Run the transition
-      !!TransitionCollection.new([self], {use_transactions: machine.use_transactions, actions: run_action}).perform
+      !!TransitionCollection.new([self], { use_transactions: machine.use_transactions, actions: run_action }).perform
     end
 
     # Runs a block within a transaction for the object being transitioned.
     # By default, transactions are a no-op unless otherwise defined by the
     # machine's integration.
-    def within_transaction
-      machine.within_transaction(object) do
-        yield
-      end
+    def within_transaction(&)
+      machine.within_transaction(object, &)
     end
 
     # Runs the before / after callbacks for this transition.  If a block is
@@ -184,15 +196,34 @@ module StateMachines
     # This will return true if all before callbacks gets executed.  After
     # callbacks will not have an effect on the result.
     def run_callbacks(options = {}, &block)
-      options = {before: true, after: true}.merge(options)
-      @success = false
+      options = { before: true, after: true }.merge(options)
 
-      halted = pausable { before(options[:after], &block) } if options[:before]
+      # If we have a paused fiber and we're not trying to resume (after: false),
+      # this is an idempotent call on an already-paused transition. Just return true.
+      return true if @paused_fiber&.alive? && !options[:after]
+
+      # Always use fibers for compatibility with existing pause/resume functionality
+      # The fiber argument can still be used to explicitly control fiber usage
+      pausable_options = options.key?(:fiber) ? { fiber: options[:fiber] } : {}
+
+      # Check if we're resuming from a pause
+      if @paused_fiber&.alive? && options[:after]
+        # Resume the paused fiber
+        # Don't reset @success when resuming - preserve the state from the pause
+        # Store the block for later execution
+        @continuation_block = block if block_given?
+        halted = pausable(pausable_options) { true }
+      else
+        @success = false
+        # For normal execution (not pause/resume), default to success
+        # The action block will override this if needed
+        halted = pausable(pausable_options) { before(options[:after], &block) } if options[:before]
+      end
 
       # After callbacks are only run if:
-      # * An around callback didn't halt after yielding
+      # * An around callback didn't halt after yielding OR the run failed
       # * They're enabled or the run didn't succeed
-      after if !(@before_run && halted) && (options[:after] || !@success)
+      after if (!(@before_run && halted) || !@success) && (options[:after] || !@success)
 
       @before_run
     end
@@ -217,10 +248,10 @@ module StateMachines
     #
     #   vehicle.state   # => 'idling'
     def persist
-      unless @persisted
-        machine.write(object, :state, to)
-        @persisted = true
-      end
+      return if @persisted
+
+      machine.write(object, :state, to)
+      @persisted = true
     end
 
     # Rolls back changes made to the object's state via this transition.  This
@@ -256,18 +287,21 @@ module StateMachines
     # the state has already been persisted
     def reset
       @before_run = @persisted = @after_run = false
-      @paused_block = nil
+      @paused_fiber = nil
+      @resuming = false
+      @continuation_block = nil
+      @fiber_thread_storage = nil
     end
 
     # Determines equality of transitions by testing whether the object, states,
     # and event involved in the transition are equal
     def ==(other)
       other.instance_of?(self.class) &&
-      other.object == object &&
-      other.machine == machine &&
-      other.from_name == from_name &&
-      other.to_name == to_name &&
-      other.event == event
+        other.object == object &&
+        other.machine == machine &&
+        other.from_name == from_name &&
+        other.to_name == to_name &&
+        other.event == event
     end
 
     # Generates a nicely formatted description of this transitions's contents.
@@ -277,10 +311,42 @@ module StateMachines
     #   transition = StateMachines::Transition.new(object, machine, :ignite, :parked, :idling)
     #   transition   # => #<StateMachines::Transition attribute=:state event=:ignite from="parked" from_name=:parked to="idling" to_name=:idling>
     def inspect
-      "#<#{self.class} #{%w(attribute event from from_name to to_name).map { |attr| "#{attr}=#{send(attr).inspect}" } * ' '}>"
+      "#<#{self.class} #{%w[attribute event from from_name to to_name].map { |attr| "#{attr}=#{send(attr).inspect}" } * ' '}>"
     end
 
-  private
+    # Checks whether this transition is currently paused.
+    # Returns true if there is a paused fiber, false otherwise.
+    def paused?
+      @paused_fiber&.alive? || false
+    end
+
+    # Checks whether this transition has a paused fiber that can be resumed.
+    # Returns true if there is a paused fiber, false otherwise.
+    #
+    # Note: The actual resuming happens automatically when run_callbacks is called
+    # again on a transition with a paused fiber.
+    def resumable?
+      paused?
+    end
+
+    # Manually resumes the execution of a previously paused callback.
+    # Returns true if the transition was successfully resumed and completed,
+    # false if there was no paused fiber, and raises an exception if the
+    # transition was halted.
+    def resume!(&block)
+      return false unless paused?
+
+      # Store continuation block if provided
+      @continuation_block = block if block_given?
+
+      # Run the pausable block which will resume the fiber
+      halted = pausable { true }
+
+      # Return whether the transition completed successfully
+      !halted
+    end
+
+    private
 
     # Runs a block that may get paused.  If the block doesn't pause, then
     # execution will continue as normal.  If the block gets paused, then it
@@ -288,17 +354,125 @@ module StateMachines
     #
     # This will return true if the given block halts for a reason other than
     # getting paused.
-    def pausable
-      begin
-        halted = !catch(:halt) { yield; true }
-      rescue => error
-        raise unless @resume_block
+    #
+    # Options:
+    # * :fiber - Whether to use fiber-based execution (default: true)
+    def pausable(options = {})
+      # If fiber is disabled, use simple synchronous execution
+      if options[:fiber] == false
+        halted = !catch(:halt) do
+          yield
+          true
+        end
+        return halted
       end
 
-      if @resume_block
-        @resume_block.call(halted, error)
+      if @paused_fiber
+        # Resume the paused fiber
+        @resuming = true
+        begin
+          result = @paused_fiber.resume
+        rescue StandardError => e
+          # Clean up on exception
+          @resuming = false
+          @paused_fiber = nil
+          raise e
+        end
+        @resuming = false
+
+        # Handle different result types
+        case result
+        when Array
+          if result[0] == :error
+            # Exception occurred inside the fiber
+            @paused_fiber = nil
+            raise result[1]
+          else
+            # Normal completion with thread storage export
+            @fiber_thread_storage = result[1] if result.length == 2 && result[1].is_a?(Hash)
+            result_value = result[0]
+          end
+        else
+          # Direct result value (paused or simple completion)
+          result_value = result
+        end
+
+        # Check if fiber is still alive after resume
+        if @paused_fiber.alive?
+          # Still paused, keep the fiber
+          true
+        else
+          # Fiber completed
+          @paused_fiber = nil
+          result_value == :halted
+        end
       else
-        halted
+        # Capture current fiber's Thread.current storage to preserve object identity
+        # This is needed for compatibility but has limitations with dynamic assignments
+        parent_fiber_locals = Thread.current.keys.each_with_object({}) do |key, storage|
+          storage[key] = Thread.current[key]
+        end
+
+        # Create a new fiber to run the block
+        fiber = Fiber.new do
+          # Restore parent's Thread.current storage with exact same object references
+          parent_fiber_locals.each do |key, value|
+            Thread.current[key] = value
+          end
+
+          # Mark that we're inside a pausable fiber
+          Fiber.current.extend(StateMachines::PausableFiber)
+          Fiber.current.state_machine_fiber_pausable = true
+          begin
+            halted = !catch(:halt) do
+              yield
+              true
+            end
+
+            # Export the final thread storage state along with the result
+            thread_storage = Thread.current.keys.each_with_object({}) do |key, storage|
+              storage[key] = Thread.current[key]
+            end
+
+            [halted ? :halted : :completed, thread_storage]
+          rescue StandardError => e
+            # Store the exception for re-raising
+            [:error, e]
+          ensure
+            # Clean up the flag
+            Fiber.current.state_machine_fiber_pausable = false
+          end
+        end
+
+        # Run the fiber
+        result = fiber.resume
+
+        # Handle different result types
+        case result
+        when Array
+          if result[0] == :error
+            # Exception occurred
+            @paused_fiber = nil
+            raise result[1]
+          else
+            # Normal completion - check if we have thread storage
+            @fiber_thread_storage = result[1] if result.length == 2 && result[1].is_a?(Hash)
+            result_value = result[0]
+          end
+        else
+          # Direct result value (shouldn't happen with our new code)
+          result_value = result
+        end
+
+        # Save if paused
+        if fiber.alive?
+          @paused_fiber = fiber
+          # Return true to indicate paused (treated as halted for flow control)
+          true
+        else
+          # Fiber completed, return whether it was halted
+          result_value == :halted
+        end
       end
     end
 
@@ -306,34 +480,23 @@ module StateMachines
     # around callbacks when the remainder of the callback will be executed at
     # a later point in time.
     def pause
-      raise ArgumentError, 'around_transition callbacks cannot be called in multiple execution contexts in java implementations of Ruby. Use before/after_transitions instead.' unless self.class.pause_supported?
+      # Don't pause if we're in the middle of resuming
+      return if @resuming
 
-      unless @resume_block
-        require 'continuation' unless defined?(callcc)
-        callcc do |block|
-          @paused_block = block
-          throw :halt, true
-        end
-      end
-    end
+      # Only yield if we're actually inside a fiber created by pausable
+      # We use a module extension to track this
+      current_fiber = Fiber.current
+      return unless current_fiber.respond_to?(:state_machine_fiber_pausable) && current_fiber.state_machine_fiber_pausable
 
-    # Resumes the execution of a previously paused callback execution.  Once
-    # the paused callbacks complete, the current execution will continue.
-    def resume
-      if @paused_block
-        halted, error = callcc do |block|
-          @resume_block = block
-          @paused_block.call
-        end
+      Fiber.yield
 
-        @resume_block = @paused_block = nil
+      # When we resume from the pause, execute the continuation block if present
+      return unless @continuation_block && !@result
 
-        raise error if error
-
-        !halted
-      else
-        true
-      end
+      action = { success: true }.merge(@continuation_block.call)
+      @result = action[:result]
+      @success = action[:success]
+      @continuation_block = nil
     end
 
     # Runs the machine's +before+ callbacks for this transition.  Only
@@ -343,35 +506,51 @@ module StateMachines
     # Once the callbacks are run, they cannot be run again until this transition
     # is reset.
     def before(complete = true, index = 0, &block)
-      unless @before_run
-        while callback = machine.callbacks[:before][index]
-          index += 1
+      return if @before_run
 
+      callback = machine.callbacks[:before][index]
+
+      if callback
+        # Check if callback matches this transition using branch
+        if callback.branch.matches?(object, context)
           if callback.type == :around
             # Around callback: need to handle recursively.  Execution only gets
             # paused if:
             # * The block fails and the callback doesn't run on failures OR
             # * The block succeeds, but after callbacks are disabled (in which
             #   case a continuation is stored for later execution)
-            return if catch(:cancel) do
-              callback.call(object, context, self) do
-                before(complete, index, &block)
+            callback.call(object, context, self) do
+              before(complete, index + 1, &block)
 
-                pause if @success && !complete
-                throw :cancel, true unless @success
-              end
+              pause if @success && !complete
+
+              # If the block failed (success is false), we should halt
+              # the around callback from continuing
+              throw :halt unless @success
             end
           else
             # Normal before callback
             callback.call(object, context, self)
+            # Continue with next callback
+            before(complete, index + 1, &block)
           end
+        else
+          # Skip to next callback if it doesn't match
+          before(complete, index + 1, &block)
+        end
+      else
+        # No more callbacks, execute the action block if at the end
+        if block_given?
+          action = { success: true }.merge(yield)
+          @result = action[:result]
+          @success = action[:success]
+        else
+          # No action block provided, default to success
+          @success = true
         end
 
         @before_run = true
       end
-
-      action = {success: true}.merge(block_given? ? yield : {})
-      @result, @success = action[:result], action[:success]
     end
 
     # Runs the machine's +after+ callbacks for this transition.  Only
@@ -388,17 +567,18 @@ module StateMachines
     # exception will not bubble up to the caller since +after+ callbacks
     # should never halt the execution of a +perform+.
     def after
-      unless @after_run
-        # First resume previously paused callbacks
-        if resume
-          catch(:halt) do
-            type = @success ? :after : :failure
-            machine.callbacks[type].each { |callback| callback.call(object, context, self) }
-          end
-        end
+      return if @after_run
 
-        @after_run = true
+      # Restore the fiber's thread storage to ensure consistency
+      # This preserves Thread.current state from before/around callbacks to after callbacks
+      @fiber_thread_storage.each { |key, value| Thread.current[key] = value } if @fiber_thread_storage
+
+      catch(:halt) do
+        type = @success ? :after : :failure
+        machine.callbacks[type].each { |callback| callback.call(object, context, self) }
       end
+
+      @after_run = true
     end
 
     # Gets a hash of the context defining this unique transition (including
@@ -410,7 +590,7 @@ module StateMachines
     #   transition = StateMachines::Transition.new(Vehicle.new, machine, :ignite, :parked, :idling)
     #   transition.context    # => {:on => :ignite, :from => :parked, :to => :idling}
     def context
-      @context ||= {on: event, from: from_name, to: to_name}
+      @context ||= { on: event, from: from_name, to: to_name }
     end
   end
 end
