@@ -1,7 +1,10 @@
+# frozen_string_literal: true
+
+require_relative 'options_validator'
+
 module StateMachines
   # Represents a collection of transitions in a state machine
   class TransitionCollection < Array
-
     # Whether to skip running the action for each transition's machine
     attr_reader :skip_actions
 
@@ -11,6 +14,9 @@ module StateMachines
     # Whether transitions should wrapped around a transaction block
     attr_reader :use_transactions
 
+    # Options passed to the collection
+    attr_reader :options
+
     # Creates a new collection of transitions that can be run in parallel.  Each
     # transition *must* be for a different attribute.
     #
@@ -23,16 +29,23 @@ module StateMachines
 
       # Determine the validity of the transitions as a whole
       @valid = all?
-      reject! { |transition| !transition }
+      reject!(&:!)
 
-      attributes = map { |transition| transition.attribute }.uniq
-      fail ArgumentError, 'Cannot perform multiple transitions in parallel for the same state machine attribute' if attributes.length != length
+      attributes = map(&:attribute).uniq
+      raise ArgumentError, 'Cannot perform multiple transitions in parallel for the same state machine attribute' if attributes.length != length
 
-      options.assert_valid_keys(:actions, :after, :use_transactions)
-      options = {actions: true, after: true, use_transactions: true}.merge(options)
+      StateMachines::OptionsValidator.assert_valid_keys!(options, :actions, :after, :use_transactions, :fiber)
+      options = { actions: true, after: true, use_transactions: true }.merge(options)
       @skip_actions = !options[:actions]
       @skip_after = !options[:after]
       @use_transactions = options[:use_transactions]
+      @options = options
+
+      # Reset transitions when creating a new collection
+      # But preserve paused transitions to allow resuming
+      each do |transition|
+        transition.reset unless transition.paused?
+      end
     end
 
     # Runs each of the collection's transitions in parallel.
@@ -72,11 +85,11 @@ module StateMachines
       end
     end
 
-  protected
+    protected
 
-    attr_reader :results #:nodoc:
+    attr_reader :results # :nodoc:
 
-  private
+    private
 
     # Is this a valid set of transitions?  If the collection was creating with
     # any +false+ values for transitions, then the the collection will be
@@ -101,7 +114,7 @@ module StateMachines
     # Gets the list of actions to run.  If configured to skip actions, then
     # this will return an empty collection.
     def actions
-      empty? ? [nil] : map { |transition| transition.action }.uniq
+      empty? ? [nil] : map(&:action).uniq
     end
 
     # Determines whether an event attribute be used to trigger the transitions
@@ -124,11 +137,21 @@ module StateMachines
     #
     # If any transition fails to run its callbacks, :halt will be thrown.
     def run_callbacks(index = 0, &block)
-      if transition = self[index]
-        throw :halt unless transition.run_callbacks(after: !skip_after) do
+      if (transition = self[index])
+        # Pass through any options that affect callback execution (e.g., fiber: false)
+        callback_options = { after: !skip_after }
+        callback_options[:fiber] = options[:fiber] if options.key?(:fiber)
+
+        callback_result = transition.run_callbacks(callback_options) do
           run_callbacks(index + 1, &block)
-          {result: results[transition.action], success: success?}
+          { result: results[transition.action], success: success? }
         end
+
+        # If we're skipping after callbacks and the transition is paused,
+        # consider it successful (the pause was intentional)
+        @success = true if skip_after && transition.paused?
+
+        throw :halt unless callback_result
       else
         persist
         run_actions(&block)
@@ -138,7 +161,7 @@ module StateMachines
     # Transitions the current value of the object's states to those specified by
     # each transition
     def persist
-      each { |transition| transition.persist }
+      each(&:persist)
     end
 
     # Runs the actions for each transition.  If a block is given method, then it
@@ -148,31 +171,29 @@ module StateMachines
     def run_actions
       catch_exceptions do
         @success = if block_given?
-          result = yield
-          actions.each { |action| results[action] = result }
-          !!result
-        else
-          actions.compact.each { |action| !skip_actions && (results[action] = object.send(action)) }
-          results.values.all?
-        end
+                     result = yield
+                     actions.each { |action| results[action] = result }
+                     !!result
+                   else
+                     actions.compact.each { |action| !skip_actions && (results[action] = object.send(action)) }
+                     results.values.all?
+                   end
       end
     end
 
     # Rolls back changes made to the object's states via each transition
     def rollback
-      each { |transition| transition.rollback }
+      each(&:rollback)
     end
 
     # Wraps the given block with a rescue handler so that any exceptions that
     # occur will automatically result in the transition rolling back any changes
     # that were made to the object involved.
     def catch_exceptions
-      begin
-        yield
-      rescue
-        rollback
-        raise
-      end
+      yield
+    rescue StandardError
+      rollback
+      raise
     end
 
     # Runs a block within a transaction for the object being transitioned.  If
@@ -192,16 +213,16 @@ module StateMachines
   # Represents a collection of transitions that were generated from attribute-
   # based events
   class AttributeTransitionCollection < TransitionCollection
-    def initialize(transitions = [], options = {}) #:nodoc:
-      super(transitions, {use_transactions: false, actions: false}.merge(options))
+    def initialize(transitions = [], options = {}) # :nodoc:
+      super(transitions, { use_transactions: false, actions: false }.merge(options))
     end
 
-  private
+    private
 
     # Hooks into running transition callbacks so that event / event transition
     # attributes can be properly updated
     def run_callbacks(index = 0)
-      if index == 0
+      if index.zero?
         # Clears any traces of the event attribute to prevent it from being
         # evaluated multiple times if actions are nested
         each do |transition|
@@ -209,19 +230,33 @@ module StateMachines
           transition.machine.write(object, :event_transition, nil)
         end
 
+        # Clear stored transitions hash for new cycle (issue #91)
+        if !empty? && (obj = first.object)
+          obj.instance_variable_set(:@_state_machine_event_transitions, nil)
+        end
+
         # Rollback only if exceptions occur during before callbacks
         begin
           super
-        rescue
+        rescue StandardError
           rollback unless @before_run
-          @success = nil  # mimics ActiveRecord.save behavior on rollback
+          @success = nil # mimics ActiveRecord.save behavior on rollback
           raise
         end
 
         # Persists transitions on the object if partial transition was successful.
         # This allows us to reference them later to complete the transition with
         # after callbacks.
-        each { |transition| transition.machine.write(object, :event_transition, transition) } if skip_after && success?
+        if skip_after && success?
+          each { |transition| transition.machine.write(object, :event_transition, transition) }
+
+          # Store transitions in a hash by machine name to avoid overwriting (issue #91)
+          unless empty?
+            transitions_by_machine = object.instance_variable_get(:@_state_machine_event_transitions) || {}
+            each { |transition| transitions_by_machine[transition.machine.name] = transition }
+            object.instance_variable_set(:@_state_machine_event_transitions, transitions_by_machine)
+          end
+        end
       else
         super
       end
