@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require_relative 'vehicle'
 
 class Car < Vehicle
   state_machine do
     event :reverse do
-      transition [:parked, :idling, :first_gear] => :backing_up
+      transition %i[parked idling first_gear] => :backing_up
     end
 
     event :park do
