@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require_relative 'vehicle'
 
 class HybridCar < Vehicle
-  attr_accessor :propulsion_mode, :driving_profile, :target_year
-  attr_accessor :energy_source, :universe, :destination
+  attr_accessor :propulsion_mode, :driving_profile, :target_year, :energy_source, :universe, :destination
 
   state_machine :propulsion_mode, initial: :gas do
     event :go_green do
@@ -42,12 +43,13 @@ class HybridCar < Vehicle
     super()
   end
 
-  def go_back_in_time(target_year, flux_capacitor_setting={}, driving_profile:)
+  def go_back_in_time(target_year, _flux_capacitor_setting = {}, driving_profile:)
     self.target_year = target_year
     self.driving_profile = driving_profile
 
     super()
   end
+
   def teleport(destination, energy_settings, universe_settings)
     self.destination = destination
     self.energy_source = energy_settings
