@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/auto_shop'
 
-class AutoShopAvailableTest < MiniTest::Test
+class AutoShopAvailableTest < Minitest::Test
   def setup
     @auto_shop = AutoShop.new
   end
