@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/traffic_light'
 
-class TrafficLightCautionTest < MiniTest::Test
+class TrafficLightCautionTest < Minitest::Test
   def setup
     @light = TrafficLight.new
     @light.state = 'caution'
@@ -12,6 +14,6 @@ class TrafficLightCautionTest < MiniTest::Test
   end
 
   def test_should_use_caution_capture_violations
-    assert_equal true, @light.capture_violations?
+    assert @light.capture_violations?
   end
 end
