@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/traffic_light'
 
-class TrafficLightProceedTest < MiniTest::Test
+class TrafficLightProceedTest < Minitest::Test
   def setup
     @light = TrafficLight.new
     @light.state = 'proceed'
@@ -12,6 +14,6 @@ class TrafficLightProceedTest < MiniTest::Test
   end
 
   def test_should_use_proceed_capture_violations
-    assert_equal false, @light.capture_violations?
+    refute_predicate @light, :capture_violations?
   end
 end
