@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/traffic_light'
 
-class TrafficLightStopTest < MiniTest::Test
+class TrafficLightStopTest < Minitest::Test
   def setup
     @light = TrafficLight.new
     @light.state = 'stop'
@@ -17,10 +19,11 @@ class TrafficLightStopTest < MiniTest::Test
 
   def test_should_pass_block_through
     color = @light.color { |value| value.upcase! }
+
     assert_equal 'RED', color
   end
 
   def test_should_use_stop_capture_violations
-    assert_equal true, @light.capture_violations?
+    assert @light.capture_violations?
   end
 end
