@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleLockedTest < MiniTest::Test
+class VehicleLockedTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.state = 'locked'
@@ -9,21 +11,25 @@ class VehicleLockedTest < MiniTest::Test
 
   def test_should_be_parked_after_park
     @vehicle.park
-    assert @vehicle.parked?
+
+    assert_predicate @vehicle, :parked?
   end
 
   def test_should_be_parked_after_ignite
     @vehicle.ignite
-    assert @vehicle.parked?
+
+    assert_predicate @vehicle, :parked?
   end
 
   def test_should_be_parked_after_shift_up
     @vehicle.shift_up
-    assert @vehicle.parked?
+
+    assert_predicate @vehicle, :parked?
   end
 
   def test_should_be_parked_after_shift_down
     @vehicle.shift_down
-    assert @vehicle.parked?
+
+    assert_predicate @vehicle, :parked?
   end
 end
