@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleParkedTest < MiniTest::Test
+class VehicleParkedTest < StateMachinesTest
   def setup
     @vehicle = Vehicle.new
   end
@@ -19,35 +21,31 @@ class VehicleParkedTest < MiniTest::Test
   end
 
   def test_should_allow_ignite
-    assert @vehicle.ignite
+    assert_sm_event_triggers(@vehicle, :ignite)
     assert_equal 'idling', @vehicle.state
   end
 
   def test_should_not_allow_idle
-    refute @vehicle.idle
+    refute_sm_event_triggers(@vehicle, :idle)
   end
 
   def test_should_not_allow_shift_up
-    refute @vehicle.shift_up
+    refute_sm_event_triggers(@vehicle, :shift_up)
   end
 
   def test_should_not_allow_shift_down
-    refute @vehicle.shift_down
+    refute_sm_event_triggers(@vehicle, :shift_down)
   end
 
   def test_should_not_allow_crash
-    refute @vehicle.crash
+    refute_sm_event_triggers(@vehicle, :crash)
   end
 
   def test_should_not_allow_repair
-    refute @vehicle.repair
+    refute_sm_event_triggers(@vehicle, :repair)
   end
 
   def test_should_raise_exception_if_repair_not_allowed!
-    exception = assert_raises(StateMachines::InvalidTransition) { @vehicle.repair! }
-    assert_equal @vehicle, exception.object
-    assert_equal Vehicle.state_machine(:state), exception.machine
-    assert_equal :repair, exception.event
-    assert_equal 'parked', exception.from
+    assert_sm_event_raises_error(@vehicle, :repair, StateMachines::InvalidTransition)
   end
 end
