@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleRepairedTest < MiniTest::Test
+class VehicleRepairedTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.ignite
@@ -15,6 +17,6 @@ class VehicleRepairedTest < MiniTest::Test
   end
 
   def test_should_not_have_a_busy_auto_shop
-    assert @vehicle.auto_shop.available?
+    assert_predicate @vehicle.auto_shop, :available?
   end
 end
