@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleSecondGearTest < MiniTest::Test
+class VehicleSecondGearTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.ignite
@@ -13,7 +15,7 @@ class VehicleSecondGearTest < MiniTest::Test
   end
 
   def test_should_be_second_gear
-    assert @vehicle.second_gear?
+    assert_predicate @vehicle, :second_gear?
   end
 
   def test_should_not_allow_park
