@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleStalledTest < MiniTest::Test
+class VehicleStalledTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.ignite
@@ -14,11 +16,11 @@ class VehicleStalledTest < MiniTest::Test
   end
 
   def test_should_be_stalled
-    assert @vehicle.stalled?
+    assert_predicate @vehicle, :stalled?
   end
 
   def test_should_be_towed
-    assert @vehicle.auto_shop.busy?
+    assert_predicate @vehicle.auto_shop, :busy?
     assert_equal 1, @vehicle.auto_shop.num_customers
   end
 
@@ -60,6 +62,7 @@ class VehicleStalledTest < MiniTest::Test
 
   def test_should_not_allow_repair_if_auto_shop_is_available
     @vehicle.auto_shop.fix_vehicle
+
     refute @vehicle.repair
   end
 end
