@@ -1,13 +1,15 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleTest < MiniTest::Test
+class VehicleTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
   end
 
   def test_should_not_allow_access_to_subclass_events
-    refute @vehicle.respond_to?(:reverse)
+    refute_respond_to @vehicle, :reverse
   end
 
   def test_should_have_human_state_names
