@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleThirdGearTest < MiniTest::Test
+class VehicleThirdGearTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.ignite
@@ -13,7 +15,7 @@ class VehicleThirdGearTest < MiniTest::Test
   end
 
   def test_should_be_third_gear
-    assert @vehicle.third_gear?
+    assert_predicate @vehicle, :third_gear?
   end
 
   def test_should_not_allow_park
