@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleUnsavedTest < MiniTest::Test
+class VehicleUnsavedTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
   end
@@ -20,30 +22,30 @@ class VehicleUnsavedTest < MiniTest::Test
   end
 
   def test_should_be_parked
-    assert @vehicle.parked?
+    assert_predicate @vehicle, :parked?
     assert @vehicle.state?(:parked)
     assert_equal :parked, @vehicle.state_name
     assert_equal 'parked', @vehicle.human_state_name
   end
 
   def test_should_not_be_idling
-    refute @vehicle.idling?
+    refute_predicate @vehicle, :idling?
   end
 
   def test_should_not_be_first_gear
-    refute @vehicle.first_gear?
+    refute_predicate @vehicle, :first_gear?
   end
 
   def test_should_not_be_second_gear
-    refute @vehicle.second_gear?
+    refute_predicate @vehicle, :second_gear?
   end
 
   def test_should_not_be_stalled
-    refute @vehicle.stalled?
+    refute_predicate @vehicle, :stalled?
   end
 
   def test_should_not_be_able_to_park
-    refute @vehicle.can_park?
+    refute_predicate @vehicle, :can_park?
   end
 
   def test_should_not_have_a_transition_for_park
@@ -55,11 +57,12 @@ class VehicleUnsavedTest < MiniTest::Test
   end
 
   def test_should_be_able_to_ignite
-    assert @vehicle.can_ignite?
+    assert_predicate @vehicle, :can_ignite?
   end
 
   def test_should_have_a_transition_for_ignite
     transition = @vehicle.ignite_transition
+
     refute_nil transition
     assert_equal 'parked', transition.from
     assert_equal 'idling', transition.to
@@ -73,7 +76,7 @@ class VehicleUnsavedTest < MiniTest::Test
   end
 
   def test_should_have_a_list_of_possible_transitions
-    assert_equal [{ object: @vehicle, attribute: :state, event: :ignite, from: 'parked', to: 'idling' }], @vehicle.state_transitions.map { |transition| transition.attributes }
+    assert_equal([{ object: @vehicle, attribute: :state, event: :ignite, from: 'parked', to: 'idling' }], @vehicle.state_transitions.map { |transition| transition.attributes })
   end
 
   def test_should_have_a_list_of_possible_paths
@@ -90,12 +93,14 @@ class VehicleUnsavedTest < MiniTest::Test
 
   def test_should_pass_arguments_through_to_generic_event_runner
     @vehicle.fire_state_event(:ignite, 1, 2, 3)
+
     assert_equal [1, 2, 3], @vehicle.last_transition_args
   end
 
   def test_should_allow_skipping_action_through_generic_event_runner
     @vehicle.fire_state_event(:ignite, false)
-    assert_equal false, @vehicle.saved
+
+    refute @vehicle.saved
   end
 
   def test_should_raise_error_with_invalid_event_through_generic_event_runer
@@ -109,7 +114,7 @@ class VehicleUnsavedTest < MiniTest::Test
 
   def test_should_allow_ignite_with_skipped_action
     assert @vehicle.ignite(false)
-    assert @vehicle.new_record?
+    assert_predicate @vehicle, :new_record?
   end
 
   def test_should_allow_ignite_bang
@@ -118,12 +123,13 @@ class VehicleUnsavedTest < MiniTest::Test
 
   def test_should_allow_ignite_bang_with_skipped_action
     assert @vehicle.ignite!(false)
-    assert @vehicle.new_record?
+    assert_predicate @vehicle, :new_record?
   end
 
   def test_should_be_saved_after_successful_event
     @vehicle.ignite
-    refute @vehicle.new_record?
+
+    refute_predicate @vehicle, :new_record?
   end
 
   def test_should_not_allow_idle
@@ -147,11 +153,11 @@ class VehicleUnsavedTest < MiniTest::Test
   end
 
   def test_should_be_insurance_inactive
-    assert @vehicle.insurance_inactive?
+    assert_predicate @vehicle, :insurance_inactive?
   end
 
   def test_should_be_able_to_buy
-    assert @vehicle.can_buy_insurance?
+    assert_predicate @vehicle, :can_buy_insurance?
   end
 
   def test_should_allow_buying_insurance
@@ -164,15 +170,15 @@ class VehicleUnsavedTest < MiniTest::Test
 
   def test_should_allow_ignite_buying_insurance_with_skipped_action
     assert @vehicle.buy_insurance!(false)
-    assert @vehicle.new_record?
+    assert_predicate @vehicle, :new_record?
   end
 
   def test_should_not_be_insurance_active
-    refute @vehicle.insurance_active?
+    refute_predicate @vehicle, :insurance_active?
   end
 
   def test_should_not_be_able_to_cancel
-    refute @vehicle.can_cancel_insurance?
+    refute_predicate @vehicle, :can_cancel_insurance?
   end
 
   def test_should_not_allow_cancelling_insurance
