@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/models/vehicle'
 
-class VehicleWithEventAttributesTest < MiniTest::Test
+class VehicleWithEventAttributesTest < Minitest::Test
   def setup
     @vehicle = Vehicle.new
     @vehicle.state_event = 'ignite'
@@ -9,12 +11,14 @@ class VehicleWithEventAttributesTest < MiniTest::Test
 
   def test_should_fail_if_event_is_invalid
     @vehicle.state_event = 'invalid'
+
     refute @vehicle.save
     assert_equal 'parked', @vehicle.state
   end
 
   def test_should_fail_if_event_has_no_transition
     @vehicle.state_event = 'park'
+
     refute @vehicle.save
     assert_equal 'parked', @vehicle.state
   end
@@ -25,6 +29,7 @@ class VehicleWithEventAttributesTest < MiniTest::Test
 
   def test_should_transition_state_on_success
     @vehicle.save
+
     assert_equal 'idling', @vehicle.state
   end
 end
