@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithExceptOnRequirementTest < StateMachinesTest
@@ -31,6 +33,6 @@ class BranchWithExceptOnRequirementTest < StateMachinesTest
   end
 
   def test_should_not_be_included_in_known_states
-    assert_equal [], @branch.known_states
+    assert_empty @branch.known_states
   end
 end
