@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithIfConditionalTest < StateMachinesTest
@@ -6,22 +8,26 @@ class BranchWithIfConditionalTest < StateMachinesTest
   end
 
   def test_should_have_an_if_condition
-    branch = StateMachines::Branch.new(if: lambda { true })
+    branch = StateMachines::Branch.new(if: -> { true })
+
     refute_nil branch.if_condition
   end
 
   def test_should_match_if_true
-    branch = StateMachines::Branch.new(if: lambda { true })
+    branch = StateMachines::Branch.new(if: -> { true })
+
     assert branch.matches?(@object)
   end
 
   def test_should_not_match_if_false
-    branch = StateMachines::Branch.new(if: lambda { false })
+    branch = StateMachines::Branch.new(if: -> { false })
+
     refute branch.matches?(@object)
   end
 
   def test_should_be_nil_if_unmatched
-    branch = StateMachines::Branch.new(if: lambda { false })
+    branch = StateMachines::Branch.new(if: -> { false })
+
     assert_nil branch.match(@object)
   end
 end
