@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithMultipleExceptOnRequirementsTest < StateMachinesTest
   def setup
     @object = Object.new
-    @branch = StateMachines::Branch.new(except_on: [:ignite, :park])
+    @branch = StateMachines::Branch.new(except_on: %i[ignite park])
   end
 
   def test_should_match_if_not_included
