@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithMultipleExceptToRequirementsTest < StateMachinesTest
   def setup
     @object = Object.new
-    @branch = StateMachines::Branch.new(except_to: [:idling, :parked])
+    @branch = StateMachines::Branch.new(except_to: %i[idling parked])
   end
 
   def test_should_match_if_not_included
@@ -15,6 +17,6 @@ class BranchWithMultipleExceptToRequirementsTest < StateMachinesTest
   end
 
   def test_should_be_included_in_known_states
-    assert_equal [:idling, :parked], @branch.known_states
+    assert_equal %i[idling parked], @branch.known_states
   end
 end
