@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithToMatcherRequirementTest < StateMachinesTest
   def setup
     @object = Object.new
-    @branch = StateMachines::Branch.new(to: StateMachines::BlacklistMatcher.new([:idling, :parked]))
+    @branch = StateMachines::Branch.new(to: StateMachines::BlacklistMatcher.new(%i[idling parked]))
   end
 
   def test_should_match_if_included
@@ -15,6 +17,6 @@ class BranchWithToMatcherRequirementTest < StateMachinesTest
   end
 
   def test_include_values_in_known_states
-    assert_equal [:idling, :parked], @branch.known_states
+    assert_equal %i[idling parked], @branch.known_states
   end
 end
