@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BranchWithoutGuardsTest < StateMachinesTest
@@ -6,22 +8,26 @@ class BranchWithoutGuardsTest < StateMachinesTest
   end
 
   def test_should_match_if_if_is_false
-    branch = StateMachines::Branch.new(if: lambda { false })
+    branch = StateMachines::Branch.new(if: -> { false })
+
     assert branch.matches?(@object, guard: false)
   end
 
   def test_should_match_if_if_is_true
-    branch = StateMachines::Branch.new(if: lambda { true })
+    branch = StateMachines::Branch.new(if: -> { true })
+
     assert branch.matches?(@object, guard: false)
   end
 
   def test_should_match_if_unless_is_false
-    branch = StateMachines::Branch.new(unless: lambda { false })
+    branch = StateMachines::Branch.new(unless: -> { false })
+
     assert branch.matches?(@object, guard: false)
   end
 
   def test_should_match_if_unless_is_true
-    branch = StateMachines::Branch.new(unless: lambda { true })
+    branch = StateMachines::Branch.new(unless: -> { true })
+
     assert branch.matches?(@object, guard: false)
   end
 end
