@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackByDefaultTest < StateMachinesTest
@@ -20,6 +22,6 @@ class CallbackByDefaultTest < StateMachinesTest
   end
 
   def test_should_not_have_any_known_states
-    assert_equal [], @callback.known_states
+    assert_empty @callback.known_states
   end
 end
