@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithArgumentsTest < StateMachinesTest
   def setup
-    @callback = StateMachines::Callback.new(:before, do: lambda { |*args| @args = args })
+    @callback = StateMachines::Callback.new(:before, do: ->(*args) { @args = args })
 
     @object = Object.new
     @callback.call(@object, {}, 1, 2, 3)
