@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithAroundTypeAndBoundMethodTest < StateMachinesTest
@@ -7,7 +9,10 @@ class CallbackWithAroundTypeAndBoundMethodTest < StateMachinesTest
 
   def test_should_call_method_within_the_context_of_the_object
     context = nil
-    callback = StateMachines::Callback.new(:around, do: lambda { |block| context = self; block.call }, bind_to_object: true)
+    callback = StateMachines::Callback.new(:around, do: lambda { |block|
+      context = self
+      block.call
+    }, bind_to_object: true)
     callback.call(@object, {}, 1, 2, 3)
 
     assert_equal @object, context
@@ -15,7 +20,11 @@ class CallbackWithAroundTypeAndBoundMethodTest < StateMachinesTest
 
   def test_should_include_arguments_if_specified
     context = nil
-    callback = StateMachines::Callback.new(:around, do: lambda { |*args| block = args.pop; context = args; block.call }, bind_to_object: true)
+    callback = StateMachines::Callback.new(:around, do: lambda { |*args|
+      block = args.pop
+      context = args
+      block.call
+    }, bind_to_object: true)
     callback.call(@object, {}, 1, 2, 3)
 
     assert_equal [1, 2, 3], context
