@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithMethodArgumentTest < StateMachinesTest
   def setup
-    @callback = StateMachines::Callback.new(:before, lambda { |*args| @args = args })
+    @callback = StateMachines::Callback.new(:before, ->(*args) { @args = args })
 
     @object = Object.new
     @result = @callback.call(@object)
