@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithUnboundMethodTest < StateMachinesTest
   def setup
-    @callback = StateMachines::Callback.new(:before, do: lambda { |*args| @context = args.unshift(self) })
+    @callback = StateMachines::Callback.new(:before, do: ->(*args) { @context = args.unshift(self) })
 
     @object = Object.new
     @callback.call(@object, {}, 1, 2, 3)
