@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithUnlessConditionTest < StateMachinesTest
@@ -6,12 +8,14 @@ class CallbackWithUnlessConditionTest < StateMachinesTest
   end
 
   def test_should_call_if_false
-    callback = StateMachines::Callback.new(:before, unless: lambda { false }, do: lambda {})
+    callback = StateMachines::Callback.new(:before, unless: -> { false }, do: -> {})
+
     assert callback.call(@object)
   end
 
   def test_should_not_call_if_true
-    callback = StateMachines::Callback.new(:before, unless: lambda { true }, do: lambda {})
+    callback = StateMachines::Callback.new(:before, unless: -> { true }, do: -> {})
+
     refute callback.call(@object)
   end
 end
