@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class CallbackWithoutArgumentsTest < StateMachinesTest
   def setup
-    @callback = StateMachines::Callback.new(:before, do: lambda { |object| @arg = object })
+    @callback = StateMachines::Callback.new(:before, do: ->(object) { @arg = object })
 
     @object = Object.new
     @callback.call(@object, {}, 1, 2, 3)
