@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class EvalHelpersBaseTest < StateMachinesTest
   include StateMachines::EvalHelpers
 
-  def default_test
-  end
+  def default_test; end
 end
