@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'unit/eval_helper/eval_helpers_base_test'
 
 class EvalHelpersProcWithBlockWithoutArgumentsTest < EvalHelpersBaseTest
   def setup
     @object = Object.new
-    @proc = lambda { |*args| args }
+    @proc = ->(*args) { args }
     class << @proc
       def arity
         0
@@ -13,7 +15,8 @@ class EvalHelpersProcWithBlockWithoutArgumentsTest < EvalHelpersBaseTest
   end
 
   def test_should_call_proc_without_arguments
-    block = lambda { true }
-    assert_equal [], evaluate_method(@object, @proc, 1, 2, 3, &block)
+    block = -> { true }
+
+    assert_empty evaluate_method(@object, @proc, 1, 2, 3, &block)
   end
 end
