@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'unit/eval_helper/eval_helpers_base_test'
 
@@ -5,6 +7,7 @@ class EvalHelpersSymbolProtectedTest < EvalHelpersBaseTest
   def setup
     class << (@object = Object.new)
       protected
+
       def callback
         true
       end
@@ -12,6 +15,6 @@ class EvalHelpersSymbolProtectedTest < EvalHelpersBaseTest
   end
 
   def test_should_call_method_on_object_with_no_arguments
-    assert_equal true, evaluate_method(@object, :callback, 1, 2, 3)
+    assert evaluate_method(@object, :callback, 1, 2, 3)
   end
 end
