@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'stringio'
 
 class EventWithConflictingHelpersBeforeDefinitionTest < StateMachinesTest
   def setup
-    @original_stderr, $stderr = $stderr, StringIO.new
+    @original_stderr = $stderr
+    $stderr = StringIO.new
 
     @superclass = Class.new do
       def can_ignite?
@@ -28,6 +31,10 @@ class EventWithConflictingHelpersBeforeDefinitionTest < StateMachinesTest
     @object = @klass.new
   end
 
+  def teardown
+    $stderr = @original_stderr
+  end
+
   def test_should_not_redefine_predicate
     assert_equal 0, @object.can_ignite?
   end
@@ -45,14 +52,10 @@ class EventWithConflictingHelpersBeforeDefinitionTest < StateMachinesTest
   end
 
   def test_should_output_warning
-    expected = %w(can_ignite? ignite_transition ignite ignite!).map do |method|
+    expected = %w[can_ignite? ignite_transition ignite ignite!].map do |method|
       "Instance method \"#{method}\" is already defined in #{@superclass}, use generic helper instead or set StateMachines::Machine.ignore_method_conflicts = true.\n"
     end.join
 
     assert_equal expected, $stderr.string
   end
-
-  def teardown
-    $stderr = @original_stderr
-  end
 end
