@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class IntegrationFinderTest < StateMachinesTest
@@ -11,6 +13,6 @@ class IntegrationFinderTest < StateMachinesTest
   end
 
   def test_should_have_no_integrations
-    assert_equal([], StateMachines::Integrations.list)
+    assert_empty(StateMachines::Integrations.list)
   end
 end
