@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class InvalidParallelTransitionTest < StateMachinesTest
   def setup
     @object = Object.new
-    @events = [:ignite, :disable_alarm]
+    @events = %i[ignite disable_alarm]
 
     @invalid_transition = StateMachines::InvalidParallelTransition.new(@object, @events)
   end
