@@ -1,10 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithActionDefinedInClassTest < StateMachinesTest
   def setup
     @klass = Class.new do
-      def save
-      end
+      def save; end
     end
 
     @machine = StateMachines::Machine.new(@klass, action: :save)
@@ -12,11 +13,11 @@ class MachineWithActionDefinedInClassTest < StateMachinesTest
   end
 
   def test_should_define_an_event_attribute_reader
-    assert @object.respond_to?(:state_event)
+    assert_respond_to @object, :state_event
   end
 
   def test_should_define_an_event_attribute_writer
-    assert @object.respond_to?(:state_event=)
+    assert_respond_to @object, :state_event=
   end
 
   def test_should_define_an_event_transition_attribute_reader
@@ -28,10 +29,10 @@ class MachineWithActionDefinedInClassTest < StateMachinesTest
   end
 
   def test_should_not_define_action
-    refute @klass.ancestors.any? { |ancestor| ancestor != @klass && ancestor.method_defined?(:save) }
+    refute(@klass.ancestors.any? { |ancestor| ancestor != @klass && ancestor.method_defined?(:save) })
   end
 
   def test_should_not_mark_action_hook_as_defined
-    refute @machine.action_hook?
+    refute_predicate @machine, :action_hook?
   end
 end
