@@ -1,17 +1,17 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithActionDefinedInIncludedModuleTest < StateMachinesTest
   def setup
     @mod = mod = Module.new do
-      def save
-      end
+      def save; end
     end
 
     @klass = Class.new do
       include mod
 
-      def bar
-      end
+      def bar; end
     end
 
     @machine = StateMachines::Machine.new(@klass, action: :save)
@@ -35,7 +35,7 @@ class MachineWithActionDefinedInIncludedModuleTest < StateMachinesTest
   end
 
   def test_should_define_action
-    assert @klass.ancestors.any? { |ancestor| ![@klass, @mod].include?(ancestor) && ancestor.method_defined?(:save) }
+    assert(@klass.ancestors.any? { |ancestor| ![@klass, @mod].include?(ancestor) && ancestor.method_defined?(:save) })
   end
 
   def test_should_keep_action_public
@@ -43,11 +43,10 @@ class MachineWithActionDefinedInIncludedModuleTest < StateMachinesTest
   end
 
   def test_should_mark_action_hook_as_defined
-    assert @machine.action_hook?
+    assert_predicate @machine, :action_hook?
   end
 
   def test_should_owner_class_ancestor_has_method_return_nil
     assert_nil @machine.send(:owner_class_ancestor_has_method?, :instance, :bar)
   end
 end
-
