@@ -1,10 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithActionDefinedInSuperclassTest < StateMachinesTest
   def setup
     @superclass = Class.new do
-      def save
-      end
+      def save; end
     end
     @klass = Class.new(@superclass)
 
@@ -13,11 +14,11 @@ class MachineWithActionDefinedInSuperclassTest < StateMachinesTest
   end
 
   def test_should_define_an_event_attribute_reader
-    assert @object.respond_to?(:state_event)
+    assert_respond_to @object, :state_event
   end
 
   def test_should_define_an_event_attribute_writer
-    assert @object.respond_to?(:state_event=)
+    assert_respond_to @object, :state_event=
   end
 
   def test_should_define_an_event_transition_attribute_reader
@@ -29,7 +30,7 @@ class MachineWithActionDefinedInSuperclassTest < StateMachinesTest
   end
 
   def test_should_define_action
-    assert @klass.ancestors.any? { |ancestor| ![@klass, @superclass].include?(ancestor) && ancestor.method_defined?(:save) }
+    assert(@klass.ancestors.any? { |ancestor| ![@klass, @superclass].include?(ancestor) && ancestor.method_defined?(:save) })
   end
 
   def test_should_keep_action_public
@@ -37,7 +38,6 @@ class MachineWithActionDefinedInSuperclassTest < StateMachinesTest
   end
 
   def test_should_mark_action_hook_as_defined
-    assert @machine.action_hook?
+    assert_predicate @machine, :action_hook?
   end
 end
-
