@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithActionUndefinedTest < StateMachinesTest
@@ -8,11 +10,11 @@ class MachineWithActionUndefinedTest < StateMachinesTest
   end
 
   def test_should_define_an_event_attribute_reader
-    assert @object.respond_to?(:state_event)
+    assert_respond_to @object, :state_event
   end
 
   def test_should_define_an_event_attribute_writer
-    assert @object.respond_to?(:state_event=)
+    assert_respond_to @object, :state_event=
   end
 
   def test_should_define_an_event_transition_attribute_reader
@@ -24,10 +26,10 @@ class MachineWithActionUndefinedTest < StateMachinesTest
   end
 
   def test_should_not_define_action
-    refute @object.respond_to?(:save)
+    refute_respond_to @object, :save
   end
 
   def test_should_not_mark_action_hook_as_defined
-    refute @machine.action_hook?
+    refute_predicate @machine, :action_hook?
   end
 end
