@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 module MachineWithCustomAttributeIntegration
@@ -31,73 +33,73 @@ class MachineWithCustomAttributeTest < StateMachinesTest
     @object = @klass.new
   end
 
+  def teardown
+    StateMachines::Integrations.reset
+  end
+
   def test_should_define_a_reader_attribute_for_the_attribute
-    assert @object.respond_to?(:state_id)
+    assert_respond_to @object, :state_id
   end
 
   def test_should_define_a_writer_attribute_for_the_attribute
-    assert @object.respond_to?(:state_id=)
+    assert_respond_to @object, :state_id=
   end
 
   def test_should_define_a_predicate_for_the_attribute
-    assert @object.respond_to?(:state?)
+    assert_respond_to @object, :state?
   end
 
   def test_should_define_a_name_reader_for_the_attribute
-    assert @object.respond_to?(:state_name)
+    assert_respond_to @object, :state_name
   end
 
   def test_should_define_a_human_name_reader_for_the_attribute
-    assert @object.respond_to?(:state_name)
+    assert_respond_to @object, :state_name
   end
 
   def test_should_define_an_event_reader_for_the_attribute
-    assert @object.respond_to?(:state_events)
+    assert_respond_to @object, :state_events
   end
 
   def test_should_define_a_transition_reader_for_the_attribute
-    assert @object.respond_to?(:state_transitions)
+    assert_respond_to @object, :state_transitions
   end
 
   def test_should_define_a_path_reader_for_the_attribute
-    assert @object.respond_to?(:state_paths)
+    assert_respond_to @object, :state_paths
   end
 
   def test_should_define_an_event_runner_for_the_attribute
-    assert @object.respond_to?(:fire_state_event)
+    assert_respond_to @object, :fire_state_event
   end
 
   def test_should_define_a_human_attribute_name_reader
-    assert @klass.respond_to?(:human_state_name)
+    assert_respond_to @klass, :human_state_name
   end
 
   def test_should_define_a_human_event_name_reader
-    assert @klass.respond_to?(:human_state_event_name)
+    assert_respond_to @klass, :human_state_event_name
   end
 
   def test_should_define_singular_with_scope
-    assert @klass.respond_to?(:with_state)
+    assert_respond_to @klass, :with_state
   end
 
   def test_should_define_singular_without_scope
-    assert @klass.respond_to?(:without_state)
+    assert_respond_to @klass, :without_state
   end
 
   def test_should_define_plural_with_scope
-    assert @klass.respond_to?(:with_states)
+    assert_respond_to @klass, :with_states
   end
 
   def test_should_define_plural_without_scope
-    assert @klass.respond_to?(:without_states)
+    assert_respond_to @klass, :without_states
   end
 
   def test_should_define_state_machines_reader
     expected = { state: @machine }
+
     assert_equal expected, @klass.state_machines
   end
-
-  def teardown
-    StateMachines::Integrations.reset
-  end
 end
-
