@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithEventMatchersTest < StateMachinesTest
@@ -7,7 +9,7 @@ class MachineWithEventMatchersTest < StateMachinesTest
   end
 
   def test_should_empty_array_for_all_matcher
-    assert_equal [], @machine.event(StateMachines::AllMatcher.instance)
+    assert_empty @machine.event(StateMachines::AllMatcher.instance)
   end
 
   def test_should_return_referenced_events_for_blacklist_matcher
@@ -15,13 +17,18 @@ class MachineWithEventMatchersTest < StateMachinesTest
   end
 
   def test_should_not_allow_configurations
-    exception = assert_raises(ArgumentError) { @machine.event(StateMachines::BlacklistMatcher.new([:park]), human_name: 'Park') }
-    assert_equal 'Cannot configure events when using matchers (using {:human_name=>"Park"})', exception.message
+    expected_hash = { human_name: 'Parked' }
+    expected_message = "Cannot configure states when using matchers (using #{expected_hash.inspect})"
+    exception = assert_raises(ArgumentError) do
+      @machine.state(StateMachines::BlacklistMatcher.new([:parked]), human_name: 'Parked')
+    end
+    assert_equal expected_message, exception.message
   end
 
   def test_should_track_referenced_events
     @machine.event(StateMachines::BlacklistMatcher.new([:park]))
-    assert_equal [:park], @machine.events.map { |event| event.name }
+
+    assert_equal([:park], @machine.events.map { |event| event.name })
   end
 
   def test_should_eval_context_for_matching_events
@@ -29,13 +36,15 @@ class MachineWithEventMatchersTest < StateMachinesTest
     @machine.event(StateMachines::BlacklistMatcher.new([:park])) { contexts_run << name }
 
     @machine.event :park
-    assert_equal [], contexts_run
+
+    assert_empty contexts_run
 
     @machine.event :ignite
+
     assert_equal [:ignite], contexts_run
 
     @machine.event :shift_up, :shift_down
-    assert_equal [:ignite, :shift_up, :shift_down], contexts_run
+
+    assert_equal %i[ignite shift_up shift_down], contexts_run
   end
 end
-
