@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithInitializeAndSuperTest < StateMachinesTest
   def setup
     @klass = Class.new do
       def initialize
-        super()
+        super
       end
     end
     @machine = StateMachines::Machine.new(@klass, initial: :parked)
