@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithStateMatchersTest < StateMachinesTest
@@ -7,7 +9,7 @@ class MachineWithStateMatchersTest < StateMachinesTest
   end
 
   def test_should_empty_array_for_all_matcher
-    assert_equal [], @machine.state(StateMachines::AllMatcher.instance)
+    assert_empty @machine.state(StateMachines::AllMatcher.instance)
   end
 
   def test_should_return_referenced_states_for_blacklist_matcher
@@ -15,13 +17,18 @@ class MachineWithStateMatchersTest < StateMachinesTest
   end
 
   def test_should_not_allow_configurations
-    exception = assert_raises(ArgumentError) { @machine.state(StateMachines::BlacklistMatcher.new([:parked]), human_name: 'Parked') }
-    assert_equal 'Cannot configure states when using matchers (using {:human_name=>"Parked"})', exception.message
+    expected_hash = { human_name: 'Parked' }
+    expected_message = "Cannot configure states when using matchers (using #{expected_hash.inspect})"
+    exception = assert_raises(ArgumentError) do
+      @machine.state(StateMachines::BlacklistMatcher.new([:parked]), human_name: 'Parked')
+    end
+    assert_equal expected_message, exception.message
   end
 
   def test_should_track_referenced_states
     @machine.state(StateMachines::BlacklistMatcher.new([:parked]))
-    assert_equal [nil, :parked], @machine.states.map { |state| state.name }
+
+    assert_equal([nil, :parked], @machine.states.map { |state| state.name })
   end
 
   def test_should_eval_context_for_matching_states
@@ -29,13 +36,15 @@ class MachineWithStateMatchersTest < StateMachinesTest
     @machine.event(StateMachines::BlacklistMatcher.new([:parked])) { contexts_run << name }
 
     @machine.event :parked
-    assert_equal [], contexts_run
+
+    assert_empty contexts_run
 
     @machine.event :idling
+
     assert_equal [:idling], contexts_run
 
     @machine.event :first_gear, :second_gear
-    assert_equal [:idling, :first_gear, :second_gear], contexts_run
+
+    assert_equal %i[idling first_gear second_gear], contexts_run
   end
 end
-
