@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithStatesWithRuntimeDependenciesTest < StateMachinesTest
@@ -8,12 +10,11 @@ class MachineWithStatesWithRuntimeDependenciesTest < StateMachinesTest
   end
 
   def test_should_not_evaluate_value_during_definition
-    @machine.state :parked, value: ->  { fail ArgumentError }
+    @machine.state :parked, value: ->  { raise ArgumentError }
   end
 
   def test_should_not_evaluate_if_not_initial_state
-    @machine.state :parked, value: ->  { fail ArgumentError }
+    @machine.state :parked, value: ->  { raise ArgumentError }
     @klass.new
   end
 end
-
