@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineWithStaticInitialStateTest < StateMachinesTest
@@ -7,18 +9,20 @@ class MachineWithStaticInitialStateTest < StateMachinesTest
   end
 
   def test_should_not_have_dynamic_initial_state
-    refute @machine.dynamic_initial_state?
+    refute_predicate @machine, :dynamic_initial_state?
   end
 
   def test_should_have_an_initial_state
     object = @klass.new
+
     assert_equal 'parked', @machine.initial_state(object).value
   end
 
   def test_should_write_to_attribute_when_initializing_state
     object = @klass.allocate
     @machine.initialize_state(object)
-    assert_equal 'parked', object.state
+
+    assert_sm_state(object, :parked)
   end
 
   def test_should_set_initial_on_state_object
@@ -26,7 +30,13 @@ class MachineWithStaticInitialStateTest < StateMachinesTest
   end
 
   def test_should_set_initial_state_on_created_object
-    assert_equal 'parked', @klass.new.state
+    object = @klass.new
+
+    assert_sm_state(object, :parked)
+  end
+
+  def test_should_have_correct_initial_state
+    assert_sm_initial_state(@machine, :parked)
   end
 
   def test_should_not_initial_state_prior_to_initialization
@@ -44,6 +54,6 @@ class MachineWithStaticInitialStateTest < StateMachinesTest
   end
 
   def test_should_be_included_in_known_states
-    assert_equal [:parked], @machine.states.keys
+    assert_sm_states_list(@machine, [:parked])
   end
 end
