@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'stringio'
 
 class MachineWithSuperclassConflictingHelpersAfterDefinitionTest < StateMachinesTest
   def setup
-    @original_stderr, $stderr = $stderr, StringIO.new
+    @original_stderr = $stderr
+    $stderr = StringIO.new
 
     @superclass = Class.new
     @klass = Class.new(@superclass)
@@ -21,16 +24,15 @@ class MachineWithSuperclassConflictingHelpersAfterDefinitionTest < StateMachines
     @object = @klass.new
   end
 
+  def teardown
+    $stderr = @original_stderr
+  end
+
   def test_should_call_superclass_attribute_predicate_without_arguments
-    assert @object.state?
+    assert_predicate @object, :state?
   end
 
   def test_should_define_attribute_predicate_with_arguments
     refute @object.state?(:parked)
   end
-
-  def teardown
-    $stderr = @original_stderr
-  end
 end
-
