@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionFireAttributesWithValidationsTest < StateMachinesTest
@@ -34,7 +36,7 @@ class MachineCollectionFireAttributesWithValidationsTest < StateMachinesTest
     @object.state_event = 'invalid'
     @machines.transitions(@object, :save)
 
-    refute @object.errors.empty?
+    refute_empty @object.errors
   end
 
   def test_should_invalidate_if_no_transition_exists
@@ -42,13 +44,13 @@ class MachineCollectionFireAttributesWithValidationsTest < StateMachinesTest
     @object.state_event = 'ignite'
     @machines.transitions(@object, :save)
 
-    refute @object.errors.empty?
+    refute_empty @object.errors
   end
 
   def test_should_not_invalidate_if_transition_exists
     @object.state_event = 'ignite'
     @machines.transitions(@object, :save)
 
-    assert @object.errors.empty?
+    assert_empty @object.errors
   end
 end
