@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionStateInitializationTest < StateMachinesTest
@@ -12,8 +14,7 @@ class MachineCollectionStateInitializationTest < StateMachinesTest
 
     # Prevent the auto-initialization hook from firing
     @klass.class_eval do
-      def initialize
-      end
+      def initialize; end
     end
 
     @object = @klass.new
@@ -53,6 +54,7 @@ class MachineCollectionStateInitializationTest < StateMachinesTest
 
   def test_should_skip_static_states_if_disabled
     @machines.initialize_states(@object, static: false)
+
     assert_nil @object.state
     assert_equal 'active', @object.alarm_state
   end
@@ -60,23 +62,27 @@ class MachineCollectionStateInitializationTest < StateMachinesTest
   def test_should_initialize_existing_static_states_by_default
     @object.state = 'idling'
     @machines.initialize_states(@object)
+
     assert_equal 'parked', @object.state
   end
 
   def test_should_initialize_existing_static_states_if_forced
     @object.state = 'idling'
     @machines.initialize_states(@object, static: :force)
+
     assert_equal 'parked', @object.state
   end
 
   def test_should_initialize_existing_static_states_if_not_forced
     @object.state = 'idling'
     @machines.initialize_states(@object, static: true)
+
     assert_equal 'parked', @object.state
   end
 
   def test_should_skip_dynamic_states_if_disabled
     @machines.initialize_states(@object, dynamic: false)
+
     assert_equal 'parked', @object.state
     assert_nil @object.alarm_state
   end
@@ -84,28 +90,33 @@ class MachineCollectionStateInitializationTest < StateMachinesTest
   def test_should_not_initialize_existing_dynamic_states_by_default
     @object.alarm_state = 'inactive'
     @machines.initialize_states(@object)
+
     assert_equal 'inactive', @object.alarm_state
   end
 
   def test_should_initialize_existing_dynamic_states_if_forced
     @object.alarm_state = 'inactive'
     @machines.initialize_states(@object, dynamic: :force)
+
     assert_equal 'active', @object.alarm_state
   end
 
   def test_should_not_initialize_existing_dynamic_states_if_not_forced
     @object.alarm_state = 'inactive'
     @machines.initialize_states(@object, dynamic: true)
+
     assert_equal 'inactive', @object.alarm_state
   end
 
   def test_shouldnt_force_state_given_either_as_string_or_symbol
     @object.state = 'notparked'
 
-    @machines.initialize_states(@object, {}, { state: "parked" })
+    @machines.initialize_states(@object, {}, { state: 'parked' })
+
     assert_equal 'notparked', @object.state
 
-    @machines.initialize_states(@object, {}, { "state" => "parked" })
+    @machines.initialize_states(@object, {}, { 'state' => 'parked' })
+
     assert_equal 'notparked', @object.state
   end
 end
