@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionTransitionsWithExisitingTransitionsTest < StateMachinesTest
@@ -20,6 +22,6 @@ class MachineCollectionTransitionsWithExisitingTransitionsTest < StateMachinesTe
   end
 
   def test_should_perform
-    assert_equal true, @transitions.perform
+    assert @transitions.perform
   end
 end
