@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionTransitionsWithInvalidEventsTest < StateMachinesTest
@@ -16,10 +18,10 @@ class MachineCollectionTransitionsWithInvalidEventsTest < StateMachinesTest
   end
 
   def test_should_be_empty
-    assert @transitions.empty?
+    assert_empty @transitions
   end
 
   def test_should_not_perform
-    assert_equal false, @transitions.perform
+    refute @transitions.perform
   end
 end
