@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionTransitionsWithSameActionsTest < StateMachinesTest
@@ -25,7 +27,6 @@ class MachineCollectionTransitionsWithSameActionsTest < StateMachinesTest
   end
 
   def test_should_perform
-    assert_equal true, @transitions.perform
+    assert @transitions.perform
   end
 end
-
