@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionTransitionsWithTransitionTest < StateMachinesTest
@@ -20,7 +22,6 @@ class MachineCollectionTransitionsWithTransitionTest < StateMachinesTest
   end
 
   def test_should_perform
-    assert_equal true, @transitions.perform
+    assert @transitions.perform
   end
 end
-
