@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class MachineCollectionTransitionsWithoutEventsTest < StateMachinesTest
@@ -16,10 +18,10 @@ class MachineCollectionTransitionsWithoutEventsTest < StateMachinesTest
   end
 
   def test_should_be_empty
-    assert @transitions.empty?
+    assert_empty @transitions
   end
 
   def test_should_perform
-    assert_equal true, @transitions.perform
+    assert @transitions.perform
   end
 end
