@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AllMatcherTest < StateMachinesTest
@@ -6,7 +8,7 @@ class AllMatcherTest < StateMachinesTest
   end
 
   def test_should_have_no_values
-    assert_equal [], @matcher.values
+    assert_empty @matcher.values
   end
 
   def test_should_always_match
@@ -14,13 +16,14 @@ class AllMatcherTest < StateMachinesTest
   end
 
   def test_should_not_filter_any_values
-    assert_equal [:parked, :idling], @matcher.filter([:parked, :idling])
+    assert_equal %i[parked idling], @matcher.filter(%i[parked idling])
   end
 
   def test_should_generate_blacklist_matcher_after_subtraction
-    matcher = @matcher - [:parked, :idling]
+    matcher = @matcher - %i[parked idling]
+
     assert_instance_of StateMachines::BlacklistMatcher, matcher
-    assert_equal [:parked, :idling], matcher.values
+    assert_equal %i[parked idling], matcher.values
   end
 
   def test_should_have_a_description
