@@ -1,16 +1,18 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class BlacklistMatcherTest < StateMachinesTest
   def setup
-    @matcher = StateMachines::BlacklistMatcher.new([:parked, :idling])
+    @matcher = StateMachines::BlacklistMatcher.new(%i[parked idling])
   end
 
   def test_should_have_values
-    assert_equal [:parked, :idling], @matcher.values
+    assert_equal %i[parked idling], @matcher.values
   end
 
   def test_should_filter_known_values
-    assert_equal [:first_gear], @matcher.filter([:parked, :idling, :first_gear])
+    assert_equal [:first_gear], @matcher.filter(%i[parked idling first_gear])
   end
 
   def test_should_match_unknown_values
@@ -25,6 +27,7 @@ class BlacklistMatcherTest < StateMachinesTest
     assert_equal 'all - [:parked, :idling]', @matcher.description
 
     matcher = StateMachines::BlacklistMatcher.new([:parked])
+
     assert_equal 'all - :parked', matcher.description
   end
 end
