@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require 'files/node'
 
 class NodeCollectionWithNumericIndexTest < StateMachinesTest
   def setup
     machine = StateMachines::Machine.new(Class.new)
-    @collection = StateMachines::NodeCollection.new(machine, index: [:name, :value])
+    @collection = StateMachines::NodeCollection.new(machine, index: %i[name value])
 
     @parked = Node.new(10, 1)
     @collection << @parked
