@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class PathByDefaultTest < StateMachinesTest
@@ -18,7 +20,7 @@ class PathByDefaultTest < StateMachinesTest
   end
 
   def test_should_not_have_walked_anywhere
-    assert_equal [], @path
+    assert_empty @path
   end
 
   def test_should_not_have_a_from_name
@@ -26,7 +28,7 @@ class PathByDefaultTest < StateMachinesTest
   end
 
   def test_should_have_no_from_states
-    assert_equal [], @path.from_states
+    assert_empty @path.from_states
   end
 
   def test_should_not_have_a_to_name
@@ -34,21 +36,21 @@ class PathByDefaultTest < StateMachinesTest
   end
 
   def test_should_have_no_to_states
-    assert_equal [], @path.to_states
+    assert_empty @path.to_states
   end
 
   def test_should_have_no_events
-    assert_equal [], @path.events
+    assert_empty @path.events
   end
 
   def test_should_not_be_able_to_walk_anywhere
     walked = false
     @path.walk { walked = true }
-    assert_equal false, walked
+
+    refute walked
   end
 
   def test_should_not_be_complete
-    assert_equal false, @path.complete?
+    refute_predicate @path, :complete?
   end
 end
-
