@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class PathWithEncounteredTransitionsTest < StateMachinesTest
@@ -16,19 +18,20 @@ class PathWithEncounteredTransitionsTest < StateMachinesTest
     @object.state = 'parked'
 
     @path = StateMachines::Path.new(@object, @machine)
-    @path.concat([
-                     @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling),
-                     @park_transition = StateMachines::Transition.new(@object, @machine, :park, :idling, :parked)
-                 ])
+    @path.push(
+                   @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling),
+                   @park_transition = StateMachines::Transition.new(@object, @machine, :park, :idling, :parked)
+                 )
   end
 
   def test_should_be_complete
-    assert_equal true, @path.complete?
+    assert @path.complete?
   end
 
   def test_should_not_be_able_to_walk
     walked = false
     @path.walk { walked = true }
-    assert_equal false, walked
+
+    refute walked
   end
 end
