@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class PathWithTransitionsTest < StateMachinesTest
@@ -11,10 +13,10 @@ class PathWithTransitionsTest < StateMachinesTest
     @object.state = 'parked'
 
     @path = StateMachines::Path.new(@object, @machine)
-    @path.concat([
-                     @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling),
-                     @shift_up_transition = StateMachines::Transition.new(@object, @machine, :shift_up, :idling, :first_gear)
-                 ])
+    @path.push(
+                   @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling),
+                   @shift_up_transition = StateMachines::Transition.new(@object, @machine, :shift_up, :idling, :first_gear)
+                 )
   end
 
   def test_should_enumerate_transitions
@@ -26,7 +28,7 @@ class PathWithTransitionsTest < StateMachinesTest
   end
 
   def test_should_have_from_states
-    assert_equal [:parked, :idling], @path.from_states
+    assert_equal %i[parked idling], @path.from_states
   end
 
   def test_should_have_a_to_name
@@ -34,21 +36,21 @@ class PathWithTransitionsTest < StateMachinesTest
   end
 
   def test_should_have_to_states
-    assert_equal [:idling, :first_gear], @path.to_states
+    assert_equal %i[idling first_gear], @path.to_states
   end
 
   def test_should_have_events
-    assert_equal [:ignite, :shift_up], @path.events
+    assert_equal %i[ignite shift_up], @path.events
   end
 
   def test_should_not_be_able_to_walk_anywhere
     walked = false
     @path.walk { walked = true }
-    assert_equal false, walked
+
+    refute walked
   end
 
   def test_should_be_complete
-    assert_equal true, @path.complete?
+    assert @path.complete?
   end
 end
-
