@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class PathWithUnreachedTargetTest < StateMachinesTest
@@ -13,19 +15,19 @@ class PathWithUnreachedTargetTest < StateMachinesTest
     @object.state = 'parked'
 
     @path = StateMachines::Path.new(@object, @machine, target: :parked)
-    @path.concat([
-                     @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
-                 ])
+    @path.push(
+                   @ignite_transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
+                 )
   end
 
   def test_should_not_be_complete
-    assert_equal false, @path.complete?
+    refute_predicate @path, :complete?
   end
 
   def test_should_not_be_able_to_walk
     walked = false
     @path.walk { walked = true }
-    assert_equal false, walked
+
+    refute walked
   end
 end
-
