@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateFinalTest < StateMachinesTest
@@ -7,7 +9,7 @@ class StateFinalTest < StateMachinesTest
   end
 
   def test_should_be_final_without_input_transitions
-    assert @state.final?
+    assert_predicate @state, :final?
   end
 
   def test_should_be_final_with_input_transitions
@@ -15,7 +17,7 @@ class StateFinalTest < StateMachinesTest
       transition idling: :parked
     end
 
-    assert @state.final?
+    assert_predicate @state, :final?
   end
 
   def test_should_be_final_with_loopback
@@ -23,6 +25,6 @@ class StateFinalTest < StateMachinesTest
       transition parked: same
     end
 
-    assert @state.final?
+    assert_predicate @state, :final?
   end
 end
