@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateNotInitialTest < StateMachinesTest
@@ -8,6 +10,6 @@ class StateNotInitialTest < StateMachinesTest
 
   def test_should_not_be_initial
     refute @state.initial
-    refute @state.initial?
+    refute_predicate @state, :initial?
   end
 end
