@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithConflictingHelpersBeforeDefinitionTest < StateMachinesTest
   def setup
-    @original_stderr, $stderr = $stderr, StringIO.new
+    @original_stderr = $stderr
+    $stderr = StringIO.new
 
     @superclass = Class.new do
       def parked?
@@ -15,15 +18,17 @@ class StateWithConflictingHelpersBeforeDefinitionTest < StateMachinesTest
     @object = @klass.new
   end
 
+  def teardown
+    $stderr = @original_stderr
+  end
+
   def test_should_not_override_state_predicate
     assert_equal 0, @object.parked?
   end
 
   def test_should_output_warning
-    assert_equal "Instance method \"parked?\" is already defined in #{@superclass}, use generic helper instead or set StateMachines::Machine.ignore_method_conflicts = true.\n", $stderr.string
-  end
-
-  def teardown
-    $stderr = @original_stderr
+    assert_match(
+      /Instance method "parked\?" is already defined in #<Class:.*>, use generic helper instead or set StateMachines::Machine.ignore_method_conflicts = true./, $stderr.string
+    )
   end
 end
