@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithContextTest < StateMachinesTest
@@ -32,7 +34,7 @@ class StateWithContextTest < StateMachinesTest
   end
 
   def test_should_return_true
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_include_new_module_in_owner_class
@@ -41,11 +43,11 @@ class StateWithContextTest < StateMachinesTest
   end
 
   def test_should_define_each_context_method_in_owner_class
-    %w(speed rpm).each { |method| assert @klass.method_defined?(method) }
+    %w[speed rpm].each { |method| assert @klass.method_defined?(method) }
   end
 
   def test_should_define_aliased_context_method_in_owner_class
-    %w(speed rpm).each { |method| assert @klass.method_defined?("__state_idling_#{method}_#{@context.object_id}__") }
+    %w[speed rpm].each { |method| assert @klass.method_defined?("__state_idling_#{method}_#{@context.object_id}__") }
   end
 
   def test_should_not_use_context_methods_as_owner_class_methods
