@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithMatcherTest < StateMachinesTest
@@ -5,7 +7,7 @@ class StateWithMatcherTest < StateMachinesTest
     @klass = Class.new
     @args = nil
     @machine = StateMachines::Machine.new(@klass)
-    @machine.states << @state = StateMachines::State.new(@machine, :parked, if: lambda { |value| value == 1 })
+    @machine.states << @state = StateMachines::State.new(@machine, :parked, if: ->(value) { value == 1 })
   end
 
   def test_should_not_match_actual_value
