@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithValidMethodCallForCurrentStateTest < StateMachinesTest
@@ -16,11 +18,11 @@ class StateWithValidMethodCallForCurrentStateTest < StateMachinesTest
   end
 
   def test_should_not_raise_an_exception
-    @state.call(@object, :speed, method_missing: lambda { fail })
+    @state.call(@object, :speed, method_missing: -> { raise })
   end
 
   def test_should_pass_arguments_through
-    assert_equal 1, @state.call(@object, :speed, 1, method_missing: lambda {})
+    assert_equal 1, @state.call(@object, :speed, 1, method_missing: -> {})
   end
 
   def test_should_pass_blocks_through
@@ -28,6 +30,6 @@ class StateWithValidMethodCallForCurrentStateTest < StateMachinesTest
   end
 
   def test_should_pass_both_arguments_and_blocks_through
-    assert_equal [1, 2], @state.call(@object, :speed, 1, method_missing: lambda {}) { 2 }
+    assert_equal [1, 2], @state.call(@object, :speed, 1, method_missing: -> {}) { 2 }
   end
 end
