@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithValidMethodCallForDifferentStateTest < StateMachinesTest
@@ -16,12 +18,12 @@ class StateWithValidMethodCallForDifferentStateTest < StateMachinesTest
   end
 
   def test_should_call_method_missing_arg
-    assert_equal 1, @state.call(@object, :speed, method_missing: lambda { 1 })
+    assert_equal 1, @state.call(@object, :speed, method_missing: -> { 1 })
   end
 
   def test_should_raise_invalid_context_on_no_method_error
     exception = assert_raises(StateMachines::InvalidContext) do
-      @state.call(@object, :speed, method_missing: lambda { fail NoMethodError.new('Invalid', :speed, []) })
+      @state.call(@object, :speed, method_missing: -> { raise NoMethodError.new('Invalid', :speed, []) })
     end
     assert_equal @object, exception.object
     assert_equal 'State nil for :state is not a valid context for calling #speed', exception.message
@@ -29,13 +31,13 @@ class StateWithValidMethodCallForDifferentStateTest < StateMachinesTest
 
   def test_should_raise_original_error_on_no_method_error_with_different_arguments
     assert_raises(NoMethodError) do
-      @state.call(@object, :speed, method_missing: lambda { fail NoMethodError.new('Invalid', :speed, [1]) })
+      @state.call(@object, :speed, method_missing: -> { raise NoMethodError.new('Invalid', :speed, [1]) })
     end
   end
 
   def test_should_raise_original_error_on_no_method_error_for_different_method
     assert_raises(NoMethodError) do
-      @state.call(@object, :speed, method_missing: lambda { fail NoMethodError.new('Invalid', :rpm, []) })
+      @state.call(@object, :speed, method_missing: -> { raise NoMethodError.new('Invalid', :rpm, []) })
     end
   end
 end
