@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateWithoutNameTest < StateMachinesTest
@@ -25,8 +27,9 @@ class StateWithoutNameTest < StateMachinesTest
 
   def test_should_not_redefine_nil_predicate
     object = @klass.new
-    refute object.nil?
-    refute object.respond_to?('?')
+
+    refute_nil object
+    refute_respond_to object, '?'
   end
 
   def test_should_have_a_description
