@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateCollectionByDefaultTest < StateMachinesTest
@@ -15,7 +17,6 @@ class StateCollectionByDefaultTest < StateMachinesTest
   end
 
   def test_should_be_empty_by_priority
-    assert_equal [], @states.by_priority
+    assert_empty @states.by_priority
   end
 end
-
