@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class StateCollectionWithStateBehaviorsTest < StateMachinesTest
@@ -18,6 +20,7 @@ class StateCollectionWithStateBehaviorsTest < StateMachinesTest
 
   def test_should_order_states_after_initial_state
     @parked.initial = true
+
     assert_equal [@parked, @idling], @states.by_priority
   end
 
@@ -25,6 +28,7 @@ class StateCollectionWithStateBehaviorsTest < StateMachinesTest
     @machine.event :ignite do
       transition from: :parked
     end
+
     assert_equal [@parked, @idling], @states.by_priority
   end
 
@@ -33,8 +37,8 @@ class StateCollectionWithStateBehaviorsTest < StateMachinesTest
   end
 
   def test_should_order_state_before_callback_states
-    @machine.before_transition from: :parked, do: lambda {}
+    @machine.before_transition from: :parked, do: -> {}
+
     assert_equal [@idling, @parked], @states.by_priority
   end
 end
-
