@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionAfterBeingPerformedTest < StateMachinesTest
@@ -23,7 +25,7 @@ class TransitionAfterBeingPerformedTest < StateMachinesTest
   end
 
   def test_should_have_empty_args
-    assert_equal [], @transition.args
+    assert_empty @transition.args
   end
 
   def test_should_have_a_result
@@ -31,7 +33,7 @@ class TransitionAfterBeingPerformedTest < StateMachinesTest
   end
 
   def test_should_be_successful
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_change_the_current_state
