@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionLoopbackTest < StateMachinesTest
@@ -13,6 +15,6 @@ class TransitionLoopbackTest < StateMachinesTest
   end
 
   def test_should_be_loopback
-    assert @transition.loopback?
+    assert_predicate @transition, :loopback?
   end
 end
