@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionTest < StateMachinesTest
@@ -74,16 +76,17 @@ class TransitionTest < StateMachinesTest
   end
 
   def test_should_not_be_transient
-    assert_equal false, @transition.transient?
+    refute_predicate @transition, :transient?
   end
 
   def test_should_generate_attributes
     expected = { object: @object, attribute: :state, event: :ignite, from: 'parked', to: 'idling' }
+
     assert_equal expected, @transition.attributes
   end
 
   def test_should_have_empty_args
-    assert_equal [], @transition.args
+    assert_empty @transition.args
   end
 
   def test_should_not_have_a_result
