@@ -1,10 +1,11 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionWithActionTest < StateMachinesTest
   def setup
     @klass = Class.new do
-      def save
-      end
+      def save; end
     end
 
     @machine = StateMachines::Machine.new(@klass, action: :save)
