@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionWithAfterCallbacksTest < StateMachinesTest
@@ -17,13 +19,13 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @machine.after_transition { |_object| @run = true }
     result = @transition.run_callbacks
 
-    assert_equal true, result
-    assert_equal true, @run
+    assert result
+    assert @run
   end
 
   def test_should_only_run_those_that_match_transition_context
     @count = 0
-    callback = lambda { @count += 1 }
+    callback = -> { @count += 1 }
 
     @machine.after_transition from: :parked, to: :idling, on: :park, do: callback
     @machine.after_transition from: :parked, to: :parked, on: :park, do: callback
@@ -38,12 +40,14 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @run = false
     @machine.after_transition { |_object| @run = true }
     @transition.run_callbacks { { success: false } }
+
     refute @run
   end
 
   def test_should_run_if_successful
     @machine.after_transition { |_object| @run = true }
     @transition.run_callbacks { { success: true } }
+
     assert @run
   end
 
@@ -51,6 +55,7 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @machine.after_transition { |*args| @args = args }
 
     @transition.run_callbacks
+
     assert_equal [@object, @transition], @args
   end
 
@@ -58,11 +63,12 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @machine.after_transition { throw :halt }
 
     result = @transition.run_callbacks
-    assert_equal true, result
+
+    assert result
   end
 
   def test_should_not_catch_exceptions
-    @machine.after_transition  { fail ArgumentError }
+    @machine.after_transition { raise ArgumentError }
     assert_raises(ArgumentError) { @transition.run_callbacks }
   end
 
@@ -71,14 +77,19 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @machine.after_transition { @count += 1 }
     @transition.run_callbacks
     @transition.run_callbacks
+
     assert_equal 1, @count
   end
 
   def test_should_not_be_able_to_run_twice_if_halted
     @count = 0
-    @machine.after_transition { @count += 1; throw :halt }
+    @machine.after_transition do
+      @count += 1
+      throw :halt
+    end
     @transition.run_callbacks
     @transition.run_callbacks
+
     assert_equal 1, @count
   end
 
@@ -88,6 +99,7 @@ class TransitionWithAfterCallbacksTest < StateMachinesTest
     @transition.run_callbacks
     @transition.reset
     @transition.run_callbacks
+
     assert_equal 2, @count
   end
 end
