@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionWithMultipleAfterCallbacksTest < StateMachinesTest
@@ -24,10 +26,13 @@ class TransitionWithMultipleAfterCallbacksTest < StateMachinesTest
 
   def test_should_not_run_further_callbacks_if_halted
     @callbacks = []
-    @machine.after_transition { @callbacks << 1; throw :halt }
+    @machine.after_transition do
+      @callbacks << 1
+      throw :halt
+    end
     @machine.after_transition { @callbacks << 2 }
 
-    assert_equal true, @transition.run_callbacks
+    assert @transition.run_callbacks
     assert_equal [1], @callbacks
   end
 
@@ -35,6 +40,6 @@ class TransitionWithMultipleAfterCallbacksTest < StateMachinesTest
     @machine.after_transition { true }
     @machine.after_transition { throw :halt }
 
-    assert_equal true, @transition.run_callbacks
+    assert @transition.run_callbacks
   end
 end
