@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionWithoutCallbacksTest < StateMachinesTest
@@ -14,20 +16,25 @@ class TransitionWithoutCallbacksTest < StateMachinesTest
   end
 
   def test_should_succeed
-    assert_equal true, @transition.run_callbacks
+    assert @transition.run_callbacks
   end
 
   def test_should_succeed_if_after_callbacks_skipped
-    assert_equal true, @transition.run_callbacks(after: false)
+    assert @transition.run_callbacks(after: false)
   end
 
   def test_should_call_block_if_provided
-    @transition.run_callbacks { @ran_block = true; {} }
+    @transition.run_callbacks do
+      @ran_block = true
+      {}
+    end
+
     assert @ran_block
   end
 
   def test_should_track_block_result
     @transition.run_callbacks { { result: 1 } }
+
     assert_equal 1, @transition.result
   end
 end
