@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AttributeTransitionCollectionByDefaultTest < StateMachinesTest
@@ -18,6 +20,6 @@ class AttributeTransitionCollectionByDefaultTest < StateMachinesTest
   end
 
   def test_should_be_empty
-    assert @transitions.empty?
+    assert_empty @transitions
   end
 end
