@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AttributeTransitionCollectionWithActionFailedTest < StateMachinesTest
@@ -17,14 +19,14 @@ class AttributeTransitionCollectionWithActionFailedTest < StateMachinesTest
     @object.status_event = 'shift_up'
 
     @transitions = StateMachines::AttributeTransitionCollection.new([
-      @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
-      @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
-    ])
+                                                                      @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
+                                                                      @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
+                                                                    ])
     @result = @transitions.perform { false }
   end
 
   def test_should_not_succeed
-    assert_equal false, @result
+    refute @result
   end
 
   def test_should_not_persist_states
