@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AttributeTransitionCollectionWithAroundCallbackAfterYieldHaltTest < StateMachinesTest
@@ -8,19 +10,22 @@ class AttributeTransitionCollectionWithAroundCallbackAfterYieldHaltTest < StateM
     @machine.state :idling
     @machine.event :ignite
 
-    @machine.around_transition { |block| block.call; throw :halt }
+    @machine.around_transition do |block|
+      block.call
+      throw :halt
+    end
 
     @object = @klass.new
     @object.state_event = 'ignite'
 
     @transitions = StateMachines::AttributeTransitionCollection.new([
-      StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
-    ])
+                                                                      StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
+                                                                    ])
     @result = @transitions.perform
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_clear_event
