@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AttributeTransitionCollectionWithAfterCallbackHaltTest < StateMachinesTest
@@ -14,13 +16,13 @@ class AttributeTransitionCollectionWithAfterCallbackHaltTest < StateMachinesTest
     @object.state_event = 'ignite'
 
     @transitions = StateMachines::AttributeTransitionCollection.new([
-      StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
-    ])
+                                                                      StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
+                                                                    ])
     @result = @transitions.perform
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_clear_event
