@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class AttributeTransitionCollectionWithEventTransitionsTest < StateMachinesTest
@@ -21,7 +23,7 @@ class AttributeTransitionCollectionWithEventTransitionsTest < StateMachinesTest
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_persist_states
