@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionEmptyWithoutBlockTest < StateMachinesTest
@@ -7,6 +9,6 @@ class TransitionCollectionEmptyWithoutBlockTest < StateMachinesTest
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 end
