@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionInvalidTest < StateMachinesTest
@@ -6,16 +8,17 @@ class TransitionCollectionInvalidTest < StateMachinesTest
   end
 
   def test_should_be_empty
-    assert @transitions.empty?
+    assert_empty @transitions
   end
 
   def test_should_not_succeed
-    assert_equal false, @transitions.perform
+    refute @transitions.perform
   end
 
   def test_should_not_run_perform_block
     ran_block = false
     @transitions.perform { ran_block = true }
+
     refute ran_block
   end
 end
