@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 require_relative 'transition_collection_with_action_hook_base_test'
 
@@ -8,7 +10,7 @@ class TransitionCollectionWithActionHookAndBlockTest < TransitionCollectionWithA
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_not_run_action
