@@ -1,5 +1,7 @@
+# frozen_string_literal: true
+
 require 'test_helper'
-require_relative 'transition_collection_with_action_hook_base_test.rb'
+require_relative 'transition_collection_with_action_hook_base_test'
 
 class TransitionCollectionWithActionHookAndSkippedAfterCallbacksTest < TransitionCollectionWithActionHookBaseTest
   def setup
@@ -8,7 +10,7 @@ class TransitionCollectionWithActionHookAndSkippedAfterCallbacksTest < Transitio
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_run_action
