@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionWithActionHookBaseTest < StateMachinesTest
@@ -29,6 +31,5 @@ class TransitionCollectionWithActionHookBaseTest < StateMachinesTest
     @transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
   end
 
-  def default_test
-  end
+  def default_test; end
 end
