@@ -1,5 +1,7 @@
+# frozen_string_literal: true
+
 require 'test_helper'
-require_relative 'transition_collection_with_action_hook_base_test.rb'
+require_relative 'transition_collection_with_action_hook_base_test'
 
 class TransitionCollectionWithActionHookInvalidTest < TransitionCollectionWithActionHookBaseTest
   def setup
@@ -8,7 +10,7 @@ class TransitionCollectionWithActionHookInvalidTest < TransitionCollectionWithAc
   end
 
   def test_should_not_succeed
-    assert_equal false, @result
+    refute @result
   end
 
   def test_should_not_run_action
