@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionWithBeforeCallbackHaltTest < StateMachinesTest
@@ -16,21 +18,28 @@ class TransitionCollectionWithBeforeCallbackHaltTest < StateMachinesTest
     @machine.state :idling
     @machine.event :ignite
 
-    @machine.before_transition { @before_count += 1; throw :halt }
+    @machine.before_transition do
+      @before_count += 1
+      throw :halt
+    end
     @machine.before_transition { @before_count += 1 }
     @machine.after_transition { @after_count += 1 }
-    @machine.around_transition { |block| @before_count += 1; block.call; @after_count += 1 }
+    @machine.around_transition do |block|
+      @before_count += 1
+      block.call
+      @after_count += 1
+    end
 
     @object = @klass.new
 
     @transitions = StateMachines::TransitionCollection.new([
-      StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
-    ])
+                                                             StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
+                                                           ])
     @result = @transitions.perform
   end
 
   def test_should_not_succeed
-    assert_equal false, @result
+    refute @result
   end
 
   def test_should_not_persist_state
