@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionWithEmptyActionsTest < StateMachinesTest
@@ -15,9 +17,9 @@ class TransitionCollectionWithEmptyActionsTest < StateMachinesTest
     @object = @klass.new
 
     @transitions = StateMachines::TransitionCollection.new([
-      @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
-      @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
-    ])
+                                                             @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
+                                                             @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
+                                                           ])
 
     @object.state = 'idling'
     @object.status = 'second_gear'
@@ -26,7 +28,7 @@ class TransitionCollectionWithEmptyActionsTest < StateMachinesTest
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_persist_states
