@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionWithMixedActionsTest < StateMachinesTest
@@ -19,14 +21,14 @@ class TransitionCollectionWithMixedActionsTest < StateMachinesTest
     @object = @klass.new
 
     @transitions = StateMachines::TransitionCollection.new([
-      @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
-      @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
-    ])
+                                                             @state_transition = StateMachines::Transition.new(@object, @state, :ignite, :parked, :idling),
+                                                             @status_transition = StateMachines::Transition.new(@object, @status, :shift_up, :first_gear, :second_gear)
+                                                           ])
     @result = @transitions.perform
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_persist_states
@@ -35,7 +37,7 @@ class TransitionCollectionWithMixedActionsTest < StateMachinesTest
   end
 
   def test_should_store_results_in_transitions
-    assert_equal true, @state_transition.result
+    assert @state_transition.result
     assert_nil @status_transition.result
   end
 end
