@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TransitionCollectionWithSkippedAfterCallbacksTest < StateMachinesTest
@@ -14,21 +16,22 @@ class TransitionCollectionWithSkippedAfterCallbacksTest < StateMachinesTest
     @object = @klass.new
 
     @transitions = StateMachines::TransitionCollection.new([
-      @transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
-    ], after: false)
+                                                             @transition = StateMachines::Transition.new(@object, @machine, :ignite, :parked, :idling)
+                                                           ], after: false)
     @result = @transitions.perform
   end
 
   def test_should_succeed
-    assert_equal true, @result
+    assert @result
   end
 
   def test_should_not_run_after_callbacks
-    refute @callbacks.include?(:after)
+    refute_includes @callbacks, :after
   end
 
   def test_should_run_after_callbacks_on_subsequent_perform
     StateMachines::TransitionCollection.new([@transition]).perform
-    assert @callbacks.include?(:after)
+
+    assert_includes @callbacks, :after
   end
 end
